Module auth

Module auth 

API token resolution.

Supports three sources (in precedence order): explicit token, the LINEAR_API_TOKEN environment variable, and a token file at any path.

Functions

token_from_env
Resolve a Linear API token from the environment variable LINEAR_API_TOKEN.
token_from_file
Resolve a Linear API token from a file at the given path.