pub struct AgentSessionUpdateInput {
pub external_link: MaybeUndefined<String>,
pub external_urls: MaybeUndefined<Vec<AgentSessionExternalUrlInput>>,
pub added_external_urls: MaybeUndefined<Vec<AgentSessionExternalUrlInput>>,
pub removed_external_urls: MaybeUndefined<Vec<String>>,
pub plan: MaybeUndefined<Value>,
pub dismissed_at: MaybeUndefined<DateTime<Utc>>,
pub user_state: MaybeUndefined<Vec<AgentSessionUserStateInput>>,
}Expand description
Input for updating an agent session.
Fields
external_link: MaybeUndefined<String>The URL of an external agent-hosted page associated with this session. Only updatable by the OAuth application that owns the session.
external_urls: MaybeUndefined<Vec<AgentSessionExternalUrlInput>>URLs of external resources associated with this session. Replaces existing URLs. Only updatable by the OAuth application that owns the session. If supplied, addedExternalUrls and removedExternalUrls are ignored.
added_external_urls: MaybeUndefined<Vec<AgentSessionExternalUrlInput>>URLs of external resources to be added to this session. Only updatable by the OAuth application that owns the session.
removed_external_urls: MaybeUndefined<Vec<String>>URLs to be removed from this session. Only updatable by the OAuth application that owns the session.
plan: MaybeUndefined<Value>A dynamically updated list of the agent’s execution strategy. Only updatable by the OAuth application that owns the session.
dismissed_at: MaybeUndefined<DateTime<Utc>>Internal The time at which the agent session was dismissed. Set to null to un-dismiss. Only updatable by internal clients.
user_state: MaybeUndefined<Vec<AgentSessionUserStateInput>>Internal User-specific state for the agent session. Only updatable by internal clients.