pub struct AiPromptProgressFilter {
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub type: MaybeUndefined<AiPromptTypeComparator>,
pub status: MaybeUndefined<AiPromptProgressStatusComparator>,
pub and: MaybeUndefined<Vec<AiPromptProgressFilter>>,
pub or: MaybeUndefined<Vec<AiPromptProgressFilter>>,
}Expand description
Internal AI prompt progress filtering options.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
type: MaybeUndefined<AiPromptTypeComparator>Internal Comparator for the AI prompt workflow type.
status: MaybeUndefined<AiPromptProgressStatusComparator>Internal Comparator for the AI prompt workflow status.
and: MaybeUndefined<Vec<AiPromptProgressFilter>>Internal Compound filters, all of which need to be matched by the AI prompt progress.
or: MaybeUndefined<Vec<AiPromptProgressFilter>>Internal Compound filters, one of which need to be matched by the AI prompt progress.