pub struct CommentFilter {Show 15 fields
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub body: MaybeUndefined<StringComparator>,
pub user: MaybeUndefined<Box<UserFilter>>,
pub issue: MaybeUndefined<Box<NullableIssueFilter>>,
pub project_update: MaybeUndefined<Box<NullableProjectUpdateFilter>>,
pub parent: MaybeUndefined<Box<NullableCommentFilter>>,
pub document_content: MaybeUndefined<Box<NullableDocumentContentFilter>>,
pub project: MaybeUndefined<Box<NullableProjectFilter>>,
pub initiative: MaybeUndefined<Box<NullableInitiativeFilter>>,
pub reactions: MaybeUndefined<ReactionCollectionFilter>,
pub needs: MaybeUndefined<Box<CustomerNeedCollectionFilter>>,
pub and: MaybeUndefined<Vec<CommentFilter>>,
pub or: MaybeUndefined<Vec<CommentFilter>>,
}Expand description
Comment filtering options.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
body: MaybeUndefined<StringComparator>Comparator for the comment’s body.
user: MaybeUndefined<Box<UserFilter>>Filters that the comment’s creator must satisfy.
issue: MaybeUndefined<Box<NullableIssueFilter>>Filters that the comment’s issue must satisfy.
project_update: MaybeUndefined<Box<NullableProjectUpdateFilter>>Filters that the comment’s project update must satisfy.
parent: MaybeUndefined<Box<NullableCommentFilter>>Filters that the comment parent must satisfy.
document_content: MaybeUndefined<Box<NullableDocumentContentFilter>>Filters that the comment’s document content must satisfy.
project: MaybeUndefined<Box<NullableProjectFilter>>Internal Filters that the comment’s project must satisfy.
initiative: MaybeUndefined<Box<NullableInitiativeFilter>>Internal Filters that the comment’s initiative must satisfy.
reactions: MaybeUndefined<ReactionCollectionFilter>Filters that the comment’s reactions must satisfy.
needs: MaybeUndefined<Box<CustomerNeedCollectionFilter>>Filters that the comment’s customer needs must satisfy.
and: MaybeUndefined<Vec<CommentFilter>>Compound filters, all of which need to be matched by the comment.
or: MaybeUndefined<Vec<CommentFilter>>Compound filters, one of which need to be matched by the comment.