pub struct CustomViewCreateInput {Show 14 fields
pub id: MaybeUndefined<String>,
pub name: String,
pub description: MaybeUndefined<String>,
pub icon: MaybeUndefined<String>,
pub color: MaybeUndefined<String>,
pub team_id: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub initiative_id: MaybeUndefined<String>,
pub owner_id: MaybeUndefined<String>,
pub filter_data: MaybeUndefined<IssueFilter>,
pub project_filter_data: MaybeUndefined<ProjectFilter>,
pub initiative_filter_data: MaybeUndefined<InitiativeFilter>,
pub feed_item_filter_data: MaybeUndefined<FeedItemFilter>,
pub shared: MaybeUndefined<bool>,
}Expand description
Input for creating a new custom view. A name is required. Optionally scope the view to a team, project, or initiative.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
name: StringThe name of the custom view.
description: MaybeUndefined<String>The description of the custom view.
icon: MaybeUndefined<String>The icon of the custom view.
color: MaybeUndefined<String>The color of the icon of the custom view.
team_id: MaybeUndefined<String>The id of the team associated with the custom view.
project_id: MaybeUndefined<String>The id of the project associated with the custom view.
initiative_id: MaybeUndefined<String>The id of the initiative associated with the custom view.
owner_id: MaybeUndefined<String>The owner of the custom view.
filter_data: MaybeUndefined<IssueFilter>The filter applied to issues in the custom view.
project_filter_data: MaybeUndefined<ProjectFilter>The project filter applied to issues in the custom view.
initiative_filter_data: MaybeUndefined<InitiativeFilter>ALPHA The initiative filter applied to issues in the custom view.
feed_item_filter_data: MaybeUndefined<FeedItemFilter>The feed item filter applied to issues in the custom view.
Whether the custom view is shared with everyone in the workspace.