pub struct CustomerCreateInput {
pub id: MaybeUndefined<String>,
pub name: String,
pub domains: MaybeUndefined<Vec<String>>,
pub external_ids: MaybeUndefined<Vec<String>>,
pub slack_channel_id: MaybeUndefined<String>,
pub owner_id: MaybeUndefined<String>,
pub status_id: MaybeUndefined<String>,
pub revenue: MaybeUndefined<i64>,
pub size: MaybeUndefined<i64>,
pub tier_id: MaybeUndefined<String>,
pub logo_url: MaybeUndefined<String>,
pub main_source_id: MaybeUndefined<String>,
}Expand description
Input for creating a new customer in the workspace.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
name: StringThe display name of the customer organization.
domains: MaybeUndefined<Vec<String>>The email domains associated with this customer (e.g., ‘acme.com’). Public email domains are not allowed. Defaults to an empty array.
external_ids: MaybeUndefined<Vec<String>>Identifiers for this customer in external systems (e.g., CRM IDs). Defaults to an empty array.
slack_channel_id: MaybeUndefined<String>The ID of the Slack channel to link to this customer.
owner_id: MaybeUndefined<String>The identifier of the user to assign as the owner of the customer.
status_id: MaybeUndefined<String>The identifier of the customer status to set.
revenue: MaybeUndefined<i64>The annual revenue generated by the customer, in dollars.
size: MaybeUndefined<i64>The size of the customer organization (e.g., number of employees).
tier_id: MaybeUndefined<String>The identifier of the customer tier to assign.
logo_url: MaybeUndefined<String>The URL of the customer’s logo image.
main_source_id: MaybeUndefined<String>The primary external source ID for customers with multiple sources. Must be one of the values provided in externalIds.