pub struct CustomerNeedCreateInput {Show 13 fields
pub id: MaybeUndefined<String>,
pub customer_id: MaybeUndefined<String>,
pub customer_external_id: MaybeUndefined<String>,
pub issue_id: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub comment_id: MaybeUndefined<String>,
pub attachment_id: MaybeUndefined<String>,
pub priority: MaybeUndefined<f64>,
pub body: MaybeUndefined<String>,
pub body_data: MaybeUndefined<Value>,
pub attachment_url: MaybeUndefined<String>,
pub create_as_user: MaybeUndefined<String>,
pub display_icon_url: MaybeUndefined<String>,
}Expand description
Input for creating a customer need linked to an issue or project. Either issueId or projectId must be provided.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
customer_id: MaybeUndefined<String>The UUID of the customer this need belongs to. Cannot be used together with customerExternalId.
customer_external_id: MaybeUndefined<String>The external system ID of the customer this need belongs to. Cannot be used together with customerId.
issue_id: MaybeUndefined<String>The issue to link this need to. Accepts a UUID or issue identifier (e.g., ‘LIN-123’). Either issueId or projectId must be provided.
project_id: MaybeUndefined<String>INTERNAL The project to link this need to. Either issueId or projectId must be provided.
comment_id: MaybeUndefined<String>The UUID of an existing comment to associate with this need for additional context.
attachment_id: MaybeUndefined<String>The UUID of an existing attachment to associate with this need as its source.
priority: MaybeUndefined<f64>Whether the customer need is important or not. 0 = Not important, 1 = Important.
body: MaybeUndefined<String>The body content of the need in Markdown format. Cannot be used together with bodyData.
body_data: MaybeUndefined<Value>Internal The body content of the need as a Prosemirror document JSON string. Cannot be used together with body.
attachment_url: MaybeUndefined<String>A URL to create an attachment from and associate with this customer need as its source.
create_as_user: MaybeUndefined<String>Create the need attributed to an external user with the provided name. This option is only available to OAuth applications creating needs in actor=app mode.
display_icon_url: MaybeUndefined<String>Avatar URL for the external user specified in createAsUser. Can only be used in conjunction with createAsUser. This option is only available to OAuth applications creating needs in actor=app mode.