pub struct CustomerNeedUpdateInput {
pub id: MaybeUndefined<String>,
pub customer_id: MaybeUndefined<String>,
pub customer_external_id: MaybeUndefined<String>,
pub issue_id: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub priority: MaybeUndefined<f64>,
pub apply_priority_to_related_needs: MaybeUndefined<bool>,
pub body: MaybeUndefined<String>,
pub body_data: MaybeUndefined<Value>,
pub attachment_url: MaybeUndefined<String>,
}Expand description
Input for updating a customer need. Supports reassigning the customer, moving to a different issue or project, changing priority, and updating body content.
Fields
id: MaybeUndefined<String>An optional identifier in UUID v4 format. If provided, will be set as the customer need’s ID.
customer_id: MaybeUndefined<String>The UUID of the customer to reassign this need to. Cannot be used together with customerExternalId.
customer_external_id: MaybeUndefined<String>The external system ID of the customer to reassign this need to. Cannot be used together with customerId.
issue_id: MaybeUndefined<String>The issue to move this need to. Accepts a UUID or issue identifier (e.g., ‘LIN-123’). The need’s attachment will also be moved to the target issue.
project_id: MaybeUndefined<String>INTERNAL The project to move this need to.
priority: MaybeUndefined<f64>Whether the customer need is important or not. 0 = Not important, 1 = Important.
When true and priority is also set, applies the same priority update to all other needs from the same customer on the same issue or project.
body: MaybeUndefined<String>The updated body content of the need in Markdown format. Set to null to clear the body. Cannot be used together with bodyData.
body_data: MaybeUndefined<Value>Internal The updated body content of the need as a Prosemirror document JSON string. Set to null to clear the body. Cannot be used together with body.
attachment_url: MaybeUndefined<String>A URL to create a new attachment from and set as the source for this customer need. Replaces any existing manually-added attachment.