pub struct CustomerTierUpdateInput {
pub name: MaybeUndefined<String>,
pub color: MaybeUndefined<String>,
pub description: MaybeUndefined<String>,
pub position: MaybeUndefined<f64>,
pub display_name: MaybeUndefined<String>,
}Expand description
Input for updating an existing customer tier.
Fields
name: MaybeUndefined<String>The updated internal name of the tier.
color: MaybeUndefined<String>The updated color of the tier indicator in the UI, as a HEX string.
description: MaybeUndefined<String>The updated description of the tier.
position: MaybeUndefined<f64>The updated sort position of the tier in the workspace’s customer tier ordering.
display_name: MaybeUndefined<String>The updated user-facing display name of the tier.