pub struct CustomerUpdateInput {
pub name: MaybeUndefined<String>,
pub domains: MaybeUndefined<Vec<String>>,
pub external_ids: MaybeUndefined<Vec<String>>,
pub slack_channel_id: MaybeUndefined<String>,
pub owner_id: MaybeUndefined<String>,
pub status_id: MaybeUndefined<String>,
pub revenue: MaybeUndefined<i64>,
pub size: MaybeUndefined<i64>,
pub tier_id: MaybeUndefined<String>,
pub logo_url: MaybeUndefined<String>,
pub main_source_id: MaybeUndefined<String>,
}Expand description
Input for updating an existing customer.
Fields
name: MaybeUndefined<String>The updated name of the customer.
domains: MaybeUndefined<Vec<String>>The updated list of email domains associated with this customer. Replaces the existing domains.
external_ids: MaybeUndefined<Vec<String>>The updated list of external system identifiers for this customer. New IDs will be appended with source metadata.
slack_channel_id: MaybeUndefined<String>The ID of the Slack channel to link to this customer. Set to null to unlink the current channel.
owner_id: MaybeUndefined<String>The identifier of the user to assign as the owner of the customer.
status_id: MaybeUndefined<String>The identifier of the customer status to set.
revenue: MaybeUndefined<i64>The annual revenue generated by the customer, in dollars.
size: MaybeUndefined<i64>The size of the customer organization (e.g., number of employees).
tier_id: MaybeUndefined<String>The identifier of the customer tier to assign.
logo_url: MaybeUndefined<String>The URL of the customer’s logo image.
main_source_id: MaybeUndefined<String>The primary external source ID for customers with multiple sources. Must be one of the values in externalIds.