pub struct CycleFilter {Show 19 fields
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub number: MaybeUndefined<NumberComparator>,
pub name: MaybeUndefined<StringComparator>,
pub starts_at: MaybeUndefined<DateComparator>,
pub ends_at: MaybeUndefined<DateComparator>,
pub completed_at: MaybeUndefined<DateComparator>,
pub is_active: MaybeUndefined<BooleanComparator>,
pub is_in_cooldown: MaybeUndefined<BooleanComparator>,
pub is_next: MaybeUndefined<BooleanComparator>,
pub is_previous: MaybeUndefined<BooleanComparator>,
pub is_future: MaybeUndefined<BooleanComparator>,
pub is_past: MaybeUndefined<BooleanComparator>,
pub team: MaybeUndefined<Box<TeamFilter>>,
pub issues: MaybeUndefined<Box<IssueCollectionFilter>>,
pub inherited_from_id: MaybeUndefined<IDComparator>,
pub and: MaybeUndefined<Vec<CycleFilter>>,
pub or: MaybeUndefined<Vec<CycleFilter>>,
}Expand description
Cycle filtering options.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
number: MaybeUndefined<NumberComparator>Comparator for the cycle number.
name: MaybeUndefined<StringComparator>Comparator for the cycle name.
starts_at: MaybeUndefined<DateComparator>Comparator for the cycle start date.
ends_at: MaybeUndefined<DateComparator>Comparator for the cycle ends at date.
completed_at: MaybeUndefined<DateComparator>Comparator for the cycle completed at date.
is_active: MaybeUndefined<BooleanComparator>Comparator for the filtering active cycle.
is_in_cooldown: MaybeUndefined<BooleanComparator>Comparator for filtering for whether the cycle is currently in cooldown.
is_next: MaybeUndefined<BooleanComparator>Comparator for the filtering next cycle.
is_previous: MaybeUndefined<BooleanComparator>Comparator for the filtering previous cycle.
is_future: MaybeUndefined<BooleanComparator>Comparator for the filtering future cycles.
is_past: MaybeUndefined<BooleanComparator>Comparator for the filtering past cycles.
team: MaybeUndefined<Box<TeamFilter>>Filters that the cycles team must satisfy.
issues: MaybeUndefined<Box<IssueCollectionFilter>>Filters that the cycles issues must satisfy.
inherited_from_id: MaybeUndefined<IDComparator>Comparator for the inherited cycle ID.
and: MaybeUndefined<Vec<CycleFilter>>Compound filters, all of which need to be matched by the cycle.
or: MaybeUndefined<Vec<CycleFilter>>Compound filters, one of which need to be matched by the cycle.