pub struct DocumentUpdateInput {Show 16 fields
pub title: MaybeUndefined<String>,
pub icon: MaybeUndefined<String>,
pub color: MaybeUndefined<String>,
pub content: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub initiative_id: MaybeUndefined<String>,
pub team_id: MaybeUndefined<String>,
pub issue_id: MaybeUndefined<String>,
pub release_id: MaybeUndefined<String>,
pub cycle_id: MaybeUndefined<String>,
pub resource_folder_id: MaybeUndefined<String>,
pub last_applied_template_id: MaybeUndefined<String>,
pub hidden_at: MaybeUndefined<DateTime<Utc>>,
pub sort_order: MaybeUndefined<f64>,
pub trashed: MaybeUndefined<bool>,
pub subscriber_ids: MaybeUndefined<Vec<String>>,
}Expand description
Input for updating an existing document.
Fields
title: MaybeUndefined<String>The title of the document.
icon: MaybeUndefined<String>The icon of the document.
color: MaybeUndefined<String>The color of the icon.
content: MaybeUndefined<String>The document content as markdown.
project_id: MaybeUndefined<String>Related project for the document.
initiative_id: MaybeUndefined<String>Internal Related initiative for the document.
team_id: MaybeUndefined<String>Internal Related team for the document.
issue_id: MaybeUndefined<String>Related issue for the document. Can be a UUID or issue identifier (e.g., ‘LIN-123’).
release_id: MaybeUndefined<String>Internal Related release for the document.
cycle_id: MaybeUndefined<String>Internal Related cycle for the document.
resource_folder_id: MaybeUndefined<String>Internal The resource folder containing the document.
last_applied_template_id: MaybeUndefined<String>The ID of the last template applied to the document.
The time at which the document was hidden. Set to null to unhide.
sort_order: MaybeUndefined<f64>The order of the item in the resources list.
trashed: MaybeUndefined<bool>Whether the document has been trashed. Set to true to trash, or null to restore from trash.
subscriber_ids: MaybeUndefined<Vec<String>>INTERNAL The identifiers of the users subscribing to this document.