pub struct EmailIntakeAddressUpdateInput {Show 15 fields
pub enabled: MaybeUndefined<bool>,
pub forwarding_email_address: MaybeUndefined<String>,
pub sender_name: MaybeUndefined<String>,
pub team_id: MaybeUndefined<String>,
pub template_id: MaybeUndefined<String>,
pub replies_enabled: MaybeUndefined<bool>,
pub use_user_names_in_replies: MaybeUndefined<bool>,
pub issue_created_auto_reply_enabled: MaybeUndefined<bool>,
pub issue_created_auto_reply: MaybeUndefined<String>,
pub issue_completed_auto_reply_enabled: MaybeUndefined<bool>,
pub issue_completed_auto_reply: MaybeUndefined<String>,
pub issue_canceled_auto_reply_enabled: MaybeUndefined<bool>,
pub issue_canceled_auto_reply: MaybeUndefined<String>,
pub customer_requests_enabled: MaybeUndefined<bool>,
pub reopen_on_reply: MaybeUndefined<bool>,
}Expand description
Input for updating an existing email intake address.
Fields
enabled: MaybeUndefined<bool>Whether the email address is currently enabled. If set to false, the email address will be disabled and no longer accept incoming emails.
forwarding_email_address: MaybeUndefined<String>The email address used to forward emails to the intake address.
sender_name: MaybeUndefined<String>The name to be used for outgoing emails.
team_id: MaybeUndefined<String>The identifier or key of the team this email address will intake issues for.
template_id: MaybeUndefined<String>The identifier of the template this email address will intake issues for.
replies_enabled: MaybeUndefined<bool>Whether email replies are enabled.
use_user_names_in_replies: MaybeUndefined<bool>Whether the commenter’s name is included in the email replies.
issue_created_auto_reply_enabled: MaybeUndefined<bool>Whether the issue created auto-reply is enabled.
issue_created_auto_reply: MaybeUndefined<String>The auto-reply message for issue created.
issue_completed_auto_reply_enabled: MaybeUndefined<bool>Whether the issue completed auto-reply is enabled.
issue_completed_auto_reply: MaybeUndefined<String>Custom auto-reply message for issue completed.
issue_canceled_auto_reply_enabled: MaybeUndefined<bool>Whether the issue canceled auto-reply is enabled.
issue_canceled_auto_reply: MaybeUndefined<String>Custom auto-reply message for issue canceled.
customer_requests_enabled: MaybeUndefined<bool>Whether customer requests are enabled.
reopen_on_reply: MaybeUndefined<bool>Whether to reopen completed or canceled issues when a substantive email reply is received.