InitiativeUpdateInput

Struct InitiativeUpdateInput 

pub struct InitiativeUpdateInput {
Show 16 fields pub name: MaybeUndefined<String>, pub description: MaybeUndefined<String>, pub owner_id: MaybeUndefined<String>, pub sort_order: MaybeUndefined<f64>, pub color: MaybeUndefined<String>, pub icon: MaybeUndefined<String>, pub target_date: MaybeUndefined<NaiveDate>, pub status: MaybeUndefined<InitiativeStatus>, pub target_date_resolution: MaybeUndefined<DateResolutionType>, pub trashed: MaybeUndefined<bool>, pub content: MaybeUndefined<String>, pub update_reminder_frequency_in_weeks: MaybeUndefined<f64>, pub update_reminder_frequency: MaybeUndefined<f64>, pub frequency_resolution: MaybeUndefined<FrequencyResolutionType>, pub update_reminders_day: MaybeUndefined<Day>, pub update_reminders_hour: MaybeUndefined<i64>,
}
The properties of the initiative to update.

Fields

name: MaybeUndefined<String>

The name of the initiative.

description: MaybeUndefined<String>

The description of the initiative.

owner_id: MaybeUndefined<String>

The owner of the initiative.

sort_order: MaybeUndefined<f64>

The sort order of the initiative within the workspace.

color: MaybeUndefined<String>

The initiative’s color.

icon: MaybeUndefined<String>

The initiative’s icon.

target_date: MaybeUndefined<NaiveDate>

The estimated completion date of the initiative. Set to null to clear.

status: MaybeUndefined<InitiativeStatus>

The initiative’s status.

target_date_resolution: MaybeUndefined<DateResolutionType>

The resolution of the initiative’s estimated completion date.

trashed: MaybeUndefined<bool>

Whether the initiative has been trashed. Set to true to trash, or null to restore.

content: MaybeUndefined<String>

The initiative’s content in markdown format.

update_reminder_frequency_in_weeks: MaybeUndefined<f64>

The n-weekly frequency at which to prompt for initiative updates. When not set, reminders are inherited from workspace settings.

update_reminder_frequency: MaybeUndefined<f64>

The frequency at which to prompt for initiative updates. When not set, reminders are inherited from workspace settings.

frequency_resolution: MaybeUndefined<FrequencyResolutionType>

The resolution type for the update reminder frequency (e.g., weekly, biweekly).

update_reminders_day: MaybeUndefined<Day>

The day of the week on which to prompt for initiative updates.

update_reminders_hour: MaybeUndefined<i64>

The hour of the day (0-23) at which to prompt for initiative updates.