pub struct InitiativeUpdatesCollectionFilter {
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub and: MaybeUndefined<Vec<InitiativeUpdatesCollectionFilter>>,
pub or: MaybeUndefined<Vec<InitiativeUpdatesCollectionFilter>>,
pub some: MaybeUndefined<InitiativeUpdatesFilter>,
pub every: MaybeUndefined<InitiativeUpdatesFilter>,
pub length: MaybeUndefined<NumberComparator>,
}Expand description
Collection filtering options for filtering initiatives by initiative updates.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
and: MaybeUndefined<Vec<InitiativeUpdatesCollectionFilter>>Compound filters, all of which need to be matched by the initiative update.
or: MaybeUndefined<Vec<InitiativeUpdatesCollectionFilter>>Compound filters, one of which need to be matched by the update.
some: MaybeUndefined<InitiativeUpdatesFilter>Filters that needs to be matched by some initiative updates.
every: MaybeUndefined<InitiativeUpdatesFilter>Filters that needs to be matched by all initiative updates.
length: MaybeUndefined<NumberComparator>Comparator for the collection length.