pub struct InitiativeUpdatesFilter {
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub and: MaybeUndefined<Vec<InitiativeUpdatesFilter>>,
pub or: MaybeUndefined<Vec<InitiativeUpdatesFilter>>,
}Expand description
Options for filtering initiatives by initiative updates.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
and: MaybeUndefined<Vec<InitiativeUpdatesFilter>>Compound filters, all of which need to be matched by the initiative updates.
or: MaybeUndefined<Vec<InitiativeUpdatesFilter>>Compound filters, one of which need to be matched by the initiative updates.