pub struct IssueCreateInput {Show 36 fields
pub id: MaybeUndefined<String>,
pub title: MaybeUndefined<String>,
pub description: MaybeUndefined<String>,
pub description_data: MaybeUndefined<Value>,
pub assignee_id: MaybeUndefined<String>,
pub delegate_id: MaybeUndefined<String>,
pub parent_id: MaybeUndefined<String>,
pub priority: MaybeUndefined<i64>,
pub estimate: MaybeUndefined<i64>,
pub subscriber_ids: MaybeUndefined<Vec<String>>,
pub label_ids: MaybeUndefined<Vec<String>>,
pub team_id: String,
pub cycle_id: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub project_milestone_id: MaybeUndefined<String>,
pub last_applied_template_id: MaybeUndefined<String>,
pub state_id: MaybeUndefined<String>,
pub reference_comment_id: MaybeUndefined<String>,
pub source_comment_id: MaybeUndefined<String>,
pub source_pull_request_comment_id: MaybeUndefined<String>,
pub sort_order: MaybeUndefined<f64>,
pub priority_sort_order: MaybeUndefined<f64>,
pub sub_issue_sort_order: MaybeUndefined<f64>,
pub due_date: MaybeUndefined<NaiveDate>,
pub create_as_user: MaybeUndefined<String>,
pub display_icon_url: MaybeUndefined<String>,
pub preserve_sort_order_on_create: MaybeUndefined<bool>,
pub created_at: MaybeUndefined<DateTime<Utc>>,
pub sla_breaches_at: MaybeUndefined<DateTime<Utc>>,
pub sla_started_at: MaybeUndefined<DateTime<Utc>>,
pub template_id: MaybeUndefined<String>,
pub completed_at: MaybeUndefined<DateTime<Utc>>,
pub sla_type: MaybeUndefined<SLADayCountType>,
pub use_default_template: MaybeUndefined<bool>,
pub release_ids: MaybeUndefined<Vec<String>>,
pub inherits_shared_access: MaybeUndefined<bool>,
}Expand description
Input for creating a new issue. At minimum, a team must be specified. A title is required unless a template is provided. All other fields are optional and will use defaults from the team or template if not specified.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
title: MaybeUndefined<String>The title of the issue.
description: MaybeUndefined<String>The issue description in markdown format.
description_data: MaybeUndefined<Value>Internal The issue description as a Prosemirror document.
assignee_id: MaybeUndefined<String>The identifier of the user to assign the issue to.
delegate_id: MaybeUndefined<String>The identifier of the agent user to delegate the issue to.
parent_id: MaybeUndefined<String>The identifier of the parent issue. Can be a UUID or issue identifier (e.g., ‘LIN-123’).
priority: MaybeUndefined<i64>The priority of the issue. 0 = No priority, 1 = Urgent, 2 = High, 3 = Medium, 4 = Low.
estimate: MaybeUndefined<i64>The estimated complexity of the issue.
subscriber_ids: MaybeUndefined<Vec<String>>The identifiers of the users subscribing to this ticket.
label_ids: MaybeUndefined<Vec<String>>The identifiers of the issue labels associated with this ticket.
team_id: StringThe identifier of the team associated with the issue.
cycle_id: MaybeUndefined<String>The cycle associated with the issue.
project_id: MaybeUndefined<String>The project associated with the issue.
project_milestone_id: MaybeUndefined<String>The project milestone associated with the issue.
last_applied_template_id: MaybeUndefined<String>The ID of the last template applied to the issue.
state_id: MaybeUndefined<String>The team state of the issue.
reference_comment_id: MaybeUndefined<String>The comment the issue is referencing.
source_comment_id: MaybeUndefined<String>The comment the issue is created from.
source_pull_request_comment_id: MaybeUndefined<String>Internal The pull request comment the issue is created from.
sort_order: MaybeUndefined<f64>The position of the issue related to other issues.
priority_sort_order: MaybeUndefined<f64>The position of the issue related to other issues, when ordered by priority.
sub_issue_sort_order: MaybeUndefined<f64>The position of the issue in parent’s sub-issue list.
due_date: MaybeUndefined<NaiveDate>The date at which the issue is due.
create_as_user: MaybeUndefined<String>Create issue as a user with the provided name. This option is only available to OAuth applications creating issues in actor=app mode.
display_icon_url: MaybeUndefined<String>Provide an external user avatar URL. Can only be used in conjunction with the createAsUser options. This option is only available to OAuth applications creating comments in actor=app mode.
preserve_sort_order_on_create: MaybeUndefined<bool>Whether the passed sort order should be preserved.
created_at: MaybeUndefined<DateTime<Utc>>The time at which the issue was created (e.g. if importing from another system). Must be a time in the past. If none is provided, the backend will generate the time as now.
sla_breaches_at: MaybeUndefined<DateTime<Utc>>Internal The time at which an issue will be considered in breach of SLA.
sla_started_at: MaybeUndefined<DateTime<Utc>>Internal The time at which the issue’s SLA was started.
template_id: MaybeUndefined<String>The identifier of a template the issue should be created from. If other values are provided in the input, they will override template values.
completed_at: MaybeUndefined<DateTime<Utc>>The time at which the issue was completed (e.g. if importing from another system). Must be a time in the past and after createdAt. Cannot be provided with an incompatible workflow state.
sla_type: MaybeUndefined<SLADayCountType>The SLA day count type for the issue. Whether SLA should be business days only or calendar days (default).
use_default_template: MaybeUndefined<bool>Whether to use the default template for the team. When set to true, the default template of this team based on user’s membership will be applied.
release_ids: MaybeUndefined<Vec<String>>ALPHA The identifiers of the releases to associate with this issue.
Internal Whether this issue should inherit shared access from its parent issue. Set to false to opt out of automatic shared access inheritance when creating a sub-issue.