pub struct IssueSortInput {Show 26 fields
pub priority: MaybeUndefined<PrioritySort>,
pub estimate: MaybeUndefined<EstimateSort>,
pub title: MaybeUndefined<TitleSort>,
pub label: MaybeUndefined<LabelSort>,
pub label_group: MaybeUndefined<LabelGroupSort>,
pub sla_status: MaybeUndefined<SlaStatusSort>,
pub created_at: MaybeUndefined<CreatedAtSort>,
pub updated_at: MaybeUndefined<UpdatedAtSort>,
pub completed_at: MaybeUndefined<CompletedAtSort>,
pub due_date: MaybeUndefined<DueDateSort>,
pub accumulated_state_updated_at: MaybeUndefined<TimeInStatusSort>,
pub cycle: MaybeUndefined<CycleSort>,
pub milestone: MaybeUndefined<MilestoneSort>,
pub assignee: MaybeUndefined<AssigneeSort>,
pub delegate: MaybeUndefined<DelegateSort>,
pub project: MaybeUndefined<ProjectSort>,
pub team: MaybeUndefined<TeamSort>,
pub manual: MaybeUndefined<ManualSort>,
pub workflow_state: MaybeUndefined<WorkflowStateSort>,
pub customer: MaybeUndefined<CustomerSort>,
pub customer_revenue: MaybeUndefined<CustomerRevenueSort>,
pub customer_count: MaybeUndefined<CustomerCountSort>,
pub customer_important_count: MaybeUndefined<CustomerImportantCountSort>,
pub root_issue: MaybeUndefined<Box<RootIssueSort>>,
pub link_count: MaybeUndefined<LinkCountSort>,
pub release: MaybeUndefined<ReleaseSort>,
}Expand description
Issue sorting options.
Fields
priority: MaybeUndefined<PrioritySort>Sort by priority
estimate: MaybeUndefined<EstimateSort>Sort by estimate
title: MaybeUndefined<TitleSort>Sort by issue title
label: MaybeUndefined<LabelSort>Sort by label
label_group: MaybeUndefined<LabelGroupSort>Sort by label group
sla_status: MaybeUndefined<SlaStatusSort>Sort by SLA status
created_at: MaybeUndefined<CreatedAtSort>Sort by issue creation date
updated_at: MaybeUndefined<UpdatedAtSort>Sort by issue update date
completed_at: MaybeUndefined<CompletedAtSort>Sort by issue completion date
due_date: MaybeUndefined<DueDateSort>Sort by issue due date
accumulated_state_updated_at: MaybeUndefined<TimeInStatusSort>Internal Sort by the accumulated time in the current workflow state
cycle: MaybeUndefined<CycleSort>Sort by Cycle start date
milestone: MaybeUndefined<MilestoneSort>Sort by Project Milestone target date
assignee: MaybeUndefined<AssigneeSort>Sort by assignee name
delegate: MaybeUndefined<DelegateSort>Sort by delegate name
project: MaybeUndefined<ProjectSort>Sort by Project name
team: MaybeUndefined<TeamSort>Sort by Team name
manual: MaybeUndefined<ManualSort>Sort by manual order
workflow_state: MaybeUndefined<WorkflowStateSort>Sort by workflow state type
customer: MaybeUndefined<CustomerSort>Sort by customer name
customer_revenue: MaybeUndefined<CustomerRevenueSort>Sort by customer revenue
customer_count: MaybeUndefined<CustomerCountSort>Sort by number of customers associated with the issue
customer_important_count: MaybeUndefined<CustomerImportantCountSort>Sort by number of important customers associated with the issue
root_issue: MaybeUndefined<Box<RootIssueSort>>Sort by the root issue
link_count: MaybeUndefined<LinkCountSort>ALPHA Sort by number of links associated with the issue
release: MaybeUndefined<ReleaseSort>ALPHA Sort by most recent release date