pub struct JiraLinearMappingInput {
pub jira_project_id: String,
pub linear_team_id: String,
pub bidirectional: MaybeUndefined<bool>,
pub default: MaybeUndefined<bool>,
pub legacy_unidirectional: MaybeUndefined<bool>,
}Fields
jira_project_id: StringThe Jira id for this project.
linear_team_id: StringThe Linear team id to map to the given project.
bidirectional: MaybeUndefined<bool>Whether the sync for this mapping is bidirectional.
default: MaybeUndefined<bool>Whether this mapping is the default one for issue creation.
legacy_unidirectional: MaybeUndefined<bool>Whether this mapping uses legacy unidirectional sync behavior where no changes sync from Linear to Jira.