pub struct JiraSettingsInput {
pub project_mapping: MaybeUndefined<Vec<JiraLinearMappingInput>>,
pub projects: Vec<JiraProjectDataInput>,
pub is_jira_server: MaybeUndefined<bool>,
pub is_custom_o_auth: MaybeUndefined<bool>,
pub personal_o_auth_client_id: MaybeUndefined<String>,
pub custom_o_auth_server_url: MaybeUndefined<String>,
pub setup_pending: MaybeUndefined<bool>,
pub manual_setup: MaybeUndefined<bool>,
pub label: MaybeUndefined<String>,
pub status_names_per_issue_type: MaybeUndefined<Value>,
}Fields
project_mapping: MaybeUndefined<Vec<JiraLinearMappingInput>>The mapping of Jira project id => Linear team id.
projects: Vec<JiraProjectDataInput>The Jira projects for the organization.
is_jira_server: MaybeUndefined<bool>Whether this integration is for Jira Server or not.
is_custom_o_auth: MaybeUndefined<bool>Whether this integration uses custom OAuth authentication (enterprise SSO).
personal_o_auth_client_id: MaybeUndefined<String>The OAuth client ID for the personal connection OAuth app, when using custom OAuth.
custom_o_auth_server_url: MaybeUndefined<String>The custom OAuth server token endpoint URL (enterprise SSO).
setup_pending: MaybeUndefined<bool>Whether the user needs to provide setup information about the webhook to complete the integration setup. Only relevant for integrations that use a manual setup flow
manual_setup: MaybeUndefined<bool>Whether this integration is using a manual setup flow.
label: MaybeUndefined<String>The label of the Jira instance, for visual identification purposes only
status_names_per_issue_type: MaybeUndefined<Value>Jira status names grouped by project, separated into issue statuses (non-Epic) and project statuses (Epic). Structure: projectId -> { issueStatuses: string[], projectStatuses: string[] }