pub struct NotificationSubscriptionCreateInput {Show 13 fields
pub id: MaybeUndefined<String>,
pub customer_id: MaybeUndefined<String>,
pub custom_view_id: MaybeUndefined<String>,
pub cycle_id: MaybeUndefined<String>,
pub initiative_id: MaybeUndefined<String>,
pub label_id: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub team_id: MaybeUndefined<String>,
pub user_id: MaybeUndefined<String>,
pub context_view_type: MaybeUndefined<ContextViewType>,
pub user_context_view_type: MaybeUndefined<UserContextViewType>,
pub notification_subscription_types: MaybeUndefined<Vec<String>>,
pub active: MaybeUndefined<bool>,
}Expand description
Input for creating a notification subscription. Exactly one target entity (customer, custom view, cycle, initiative, label, project, team, or user) must be specified along with the notification types to subscribe to.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
customer_id: MaybeUndefined<String>The identifier of the customer to subscribe to.
custom_view_id: MaybeUndefined<String>The identifier of the custom view to subscribe to.
cycle_id: MaybeUndefined<String>The identifier of the cycle to subscribe to.
initiative_id: MaybeUndefined<String>The identifier of the initiative to subscribe to.
label_id: MaybeUndefined<String>The identifier of the label to subscribe to.
project_id: MaybeUndefined<String>The identifier of the project to subscribe to.
team_id: MaybeUndefined<String>The identifier of the team to subscribe to.
user_id: MaybeUndefined<String>The identifier of the user to subscribe to.
context_view_type: MaybeUndefined<ContextViewType>The type of view to which the notification subscription context is associated with.
user_context_view_type: MaybeUndefined<UserContextViewType>The type of user view to which the notification subscription context is associated with.
notification_subscription_types: MaybeUndefined<Vec<String>>The specific notification event types the subscriber wants to receive for the target entity.
active: MaybeUndefined<bool>Whether the subscription is active. Set to false to pause notifications without deleting the subscription.