pub struct NullableInitiativeFilter {Show 20 fields
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub name: MaybeUndefined<StringComparator>,
pub slug_id: MaybeUndefined<StringComparator>,
pub creator: MaybeUndefined<Box<NullableUserFilter>>,
pub status: MaybeUndefined<StringComparator>,
pub teams: MaybeUndefined<Box<TeamCollectionFilter>>,
pub owner: MaybeUndefined<Box<NullableUserFilter>>,
pub target_date: MaybeUndefined<NullableDateComparator>,
pub started_at: MaybeUndefined<NullableDateComparator>,
pub completed_at: MaybeUndefined<NullableDateComparator>,
pub health: MaybeUndefined<StringComparator>,
pub health_with_age: MaybeUndefined<StringComparator>,
pub activity_type: MaybeUndefined<StringComparator>,
pub ancestors: MaybeUndefined<Box<InitiativeCollectionFilter>>,
pub initiative_updates: MaybeUndefined<InitiativeUpdatesCollectionFilter>,
pub null: MaybeUndefined<bool>,
pub and: MaybeUndefined<Vec<NullableInitiativeFilter>>,
pub or: MaybeUndefined<Vec<NullableInitiativeFilter>>,
}Expand description
Initiative filtering options.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
name: MaybeUndefined<StringComparator>Comparator for the initiative name.
slug_id: MaybeUndefined<StringComparator>Comparator for the initiative slug ID.
creator: MaybeUndefined<Box<NullableUserFilter>>Filters that the initiative creator must satisfy.
status: MaybeUndefined<StringComparator>Comparator for the initiative status: Planned, Active, Completed
teams: MaybeUndefined<Box<TeamCollectionFilter>>Filters that the initiative teams must satisfy.
owner: MaybeUndefined<Box<NullableUserFilter>>Filters that the initiative owner must satisfy.
target_date: MaybeUndefined<NullableDateComparator>Comparator for the initiative target date.
started_at: MaybeUndefined<NullableDateComparator>Comparator for the initiative started at date.
completed_at: MaybeUndefined<NullableDateComparator>Comparator for the initiative completed at date.
health: MaybeUndefined<StringComparator>Comparator for the initiative health: onTrack, atRisk, offTrack
health_with_age: MaybeUndefined<StringComparator>Comparator for the initiative health (with age): onTrack, atRisk, offTrack, outdated, noUpdate
activity_type: MaybeUndefined<StringComparator>Comparator for the initiative activity type.
ancestors: MaybeUndefined<Box<InitiativeCollectionFilter>>Filters that the initiative must be an ancestor of.
initiative_updates: MaybeUndefined<InitiativeUpdatesCollectionFilter>Filters that the initiative updates must satisfy.
null: MaybeUndefined<bool>Filter based on the existence of the relation.
and: MaybeUndefined<Vec<NullableInitiativeFilter>>Compound filters, all of which need to be matched by the initiative.
or: MaybeUndefined<Vec<NullableInitiativeFilter>>Compound filters, one of which need to be matched by the initiative.