pub struct OrganizationLinearAgentSettingsInput {
pub web_search_enabled: MaybeUndefined<bool>,
pub mcp_servers_enabled: MaybeUndefined<bool>,
pub mcp_servers_allowlist: MaybeUndefined<Vec<OrganizationLinearAgentMcpServerAllowlistEntryInput>>,
}Expand description
Internal Input for updating Linear Agent settings for the workspace.
Fields
web_search_enabled: MaybeUndefined<bool>Internal Whether the workspace has enabled web search for Linear Agent.
mcp_servers_enabled: MaybeUndefined<bool>Internal Whether the workspace has enabled MCP servers for Linear Agent.
mcp_servers_allowlist: MaybeUndefined<Vec<OrganizationLinearAgentMcpServerAllowlistEntryInput>>Internal The MCP server allowlist for Linear Agent. When unset, all MCP servers are allowed.