pub struct OrganizationUpdateInput {Show 48 fields
pub name: MaybeUndefined<String>,
pub logo_url: MaybeUndefined<String>,
pub url_key: MaybeUndefined<String>,
pub git_branch_format: MaybeUndefined<String>,
pub git_linkback_messages_enabled: MaybeUndefined<bool>,
pub git_public_linkback_messages_enabled: MaybeUndefined<bool>,
pub git_linkback_descriptions_enabled: MaybeUndefined<bool>,
pub roadmap_enabled: MaybeUndefined<bool>,
pub project_update_reminder_frequency_in_weeks: MaybeUndefined<f64>,
pub project_update_reminders_day: MaybeUndefined<Day>,
pub project_update_reminders_hour: MaybeUndefined<f64>,
pub initiative_update_reminder_frequency_in_weeks: MaybeUndefined<f64>,
pub initiative_update_reminders_day: MaybeUndefined<Day>,
pub initiative_update_reminders_hour: MaybeUndefined<f64>,
pub fiscal_year_start_month: MaybeUndefined<f64>,
pub working_days: MaybeUndefined<Vec<f64>>,
pub reduced_personal_information: MaybeUndefined<bool>,
pub oauth_app_review: MaybeUndefined<bool>,
pub allowed_auth_services: MaybeUndefined<Vec<String>>,
pub sla_enabled: MaybeUndefined<bool>,
pub restrict_agent_invocation_to_members: MaybeUndefined<bool>,
pub ip_restrictions: MaybeUndefined<Vec<OrganizationIpRestrictionInput>>,
pub allowed_file_upload_content_types: MaybeUndefined<Vec<String>>,
pub theme_settings: MaybeUndefined<Value>,
pub customers_enabled: MaybeUndefined<bool>,
pub customers_configuration: MaybeUndefined<Value>,
pub code_intelligence_enabled: MaybeUndefined<bool>,
pub code_intelligence_repository: MaybeUndefined<String>,
pub feed_enabled: MaybeUndefined<bool>,
pub hide_non_primary_organizations: MaybeUndefined<bool>,
pub default_feed_summary_schedule: MaybeUndefined<FeedSummarySchedule>,
pub ai_addon_enabled: MaybeUndefined<bool>,
pub agent_automation_enabled: MaybeUndefined<bool>,
pub generated_updates_enabled: MaybeUndefined<bool>,
pub ai_telemetry_enabled: MaybeUndefined<bool>,
pub ai_discussion_summaries_enabled: MaybeUndefined<bool>,
pub ai_thread_summaries_enabled: MaybeUndefined<bool>,
pub hipaa_compliance_enabled: MaybeUndefined<bool>,
pub security_settings: MaybeUndefined<OrganizationSecuritySettingsInput>,
pub auth_settings: MaybeUndefined<OrganizationAuthSettingsInput>,
pub ai_provider_configuration: MaybeUndefined<Value>,
pub slack_project_channel_integration_id: MaybeUndefined<String>,
pub slack_project_channel_prefix: MaybeUndefined<String>,
pub slack_project_channels_enabled: MaybeUndefined<bool>,
pub slack_auto_create_project_channel: MaybeUndefined<bool>,
pub linear_agent_enabled: MaybeUndefined<bool>,
pub linear_agent_settings: MaybeUndefined<OrganizationLinearAgentSettingsInput>,
pub coding_agent_enabled: MaybeUndefined<bool>,
}Expand description
Input for updating the workspace.
Fields
name: MaybeUndefined<String>The name of the workspace.
logo_url: MaybeUndefined<String>The logo URL of the workspace.
url_key: MaybeUndefined<String>The URL key of the workspace.
git_branch_format: MaybeUndefined<String>How git branches are formatted. If null, default formatting will be used.
git_linkback_messages_enabled: MaybeUndefined<bool>Whether the Git integration linkback messages should be sent for private repositories.
git_public_linkback_messages_enabled: MaybeUndefined<bool>Whether the Git integration linkback messages should be sent for public repositories.
git_linkback_descriptions_enabled: MaybeUndefined<bool>Whether issue descriptions should be included in Git integration linkback messages.
roadmap_enabled: MaybeUndefined<bool>Whether the workspace is using roadmap.
project_update_reminder_frequency_in_weeks: MaybeUndefined<f64>The n-weekly frequency at which to prompt for project updates.
project_update_reminders_day: MaybeUndefined<Day>The day at which project updates are sent.
project_update_reminders_hour: MaybeUndefined<f64>The hour at which project updates are sent.
initiative_update_reminder_frequency_in_weeks: MaybeUndefined<f64>ALPHA The n-weekly frequency at which to prompt for initiative updates.
initiative_update_reminders_day: MaybeUndefined<Day>ALPHA The day at which initiative updates are sent.
initiative_update_reminders_hour: MaybeUndefined<f64>ALPHA The hour at which initiative updates are sent.
fiscal_year_start_month: MaybeUndefined<f64>The month at which the fiscal year starts.
working_days: MaybeUndefined<Vec<f64>>Internal The list of working days. Sunday is 0, Monday is 1, etc.
reduced_personal_information: MaybeUndefined<bool>Whether the workspace has opted for reduced customer support attachment information.
oauth_app_review: MaybeUndefined<bool>Whether the workspace has opted for having to approve all OAuth applications for install.
allowed_auth_services: MaybeUndefined<Vec<String>>List of services that are allowed to be used for login.
sla_enabled: MaybeUndefined<bool>Internal. Whether SLAs have been enabled for the workspace.
restrict_agent_invocation_to_members: MaybeUndefined<bool>Whether agent invocation is restricted to full workspace members.
ip_restrictions: MaybeUndefined<Vec<OrganizationIpRestrictionInput>>IP restriction configurations controlling allowed access the workspace.
allowed_file_upload_content_types: MaybeUndefined<Vec<String>>Allowed file upload content types.
theme_settings: MaybeUndefined<Value>ALPHA Theme settings for the workspace.
customers_enabled: MaybeUndefined<bool>INTERNAL Whether the workspace is using customers.
customers_configuration: MaybeUndefined<Value>INTERNAL Configuration settings for the Customers feature.
code_intelligence_enabled: MaybeUndefined<bool>INTERNAL Whether code intelligence is enabled for the workspace.
code_intelligence_repository: MaybeUndefined<String>INTERNAL GitHub repository in owner/repo format for code intelligence.
feed_enabled: MaybeUndefined<bool>Whether the workspace has enabled the feed feature.
hide_non_primary_organizations: MaybeUndefined<bool>Whether to hide other workspaces for new users signing up with email domains claimed by this organization.
default_feed_summary_schedule: MaybeUndefined<FeedSummarySchedule>Default schedule for how often feed summaries are generated.
ai_addon_enabled: MaybeUndefined<bool>INTERNAL Whether the workspace has enabled the AI add-on.
agent_automation_enabled: MaybeUndefined<bool>INTERNAL Whether the workspace has enabled agent automation.
generated_updates_enabled: MaybeUndefined<bool>INTERNAL Whether the workspace has enabled generated updates.
ai_telemetry_enabled: MaybeUndefined<bool>INTERNAL Whether the workspace has opted in to AI telemetry.
ai_discussion_summaries_enabled: MaybeUndefined<bool>Whether the workspace has enabled AI discussion summaries for issues.
ai_thread_summaries_enabled: MaybeUndefined<bool>Whether the workspace has enabled resolved thread AI summaries.
hipaa_compliance_enabled: MaybeUndefined<bool>Whether HIPAA compliance is enabled for the workspace.
security_settings: MaybeUndefined<OrganizationSecuritySettingsInput>The security settings for the workspace.
auth_settings: MaybeUndefined<OrganizationAuthSettingsInput>The authentication settings for the workspace.
ai_provider_configuration: MaybeUndefined<Value>INTERNAL Configure per-modality AI host providers and model families.
slack_project_channel_integration_id: MaybeUndefined<String>The ID of the Slack integration to use for auto-creating project channels.
slack_project_channel_prefix: MaybeUndefined<String>The prefix to use for auto-created Slack project channels (p-, proj-, or project-).
slack_project_channels_enabled: MaybeUndefined<bool>Internal Whether the Slack project channels feature is enabled for the workspace.
slack_auto_create_project_channel: MaybeUndefined<bool>Internal Whether to automatically create a Slack channel when a new project is created.
linear_agent_enabled: MaybeUndefined<bool>Internal Whether the workspace has enabled Linear Agent.
linear_agent_settings: MaybeUndefined<OrganizationLinearAgentSettingsInput>Internal Settings for Linear Agent features.
coding_agent_enabled: MaybeUndefined<bool>INTERNAL Whether the workspace has enabled the Coding Agent.