pub struct ProjectCollectionFilter {Show 44 fields
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub name: MaybeUndefined<StringComparator>,
pub slug_id: MaybeUndefined<StringComparator>,
pub state: MaybeUndefined<StringComparator>,
pub status: MaybeUndefined<Box<ProjectStatusFilter>>,
pub priority: MaybeUndefined<NullableNumberComparator>,
pub labels: MaybeUndefined<Box<ProjectLabelCollectionFilter>>,
pub searchable_content: MaybeUndefined<ContentComparator>,
pub started_at: MaybeUndefined<NullableDateComparator>,
pub completed_at: MaybeUndefined<NullableDateComparator>,
pub canceled_at: MaybeUndefined<NullableDateComparator>,
pub start_date: MaybeUndefined<NullableDateComparator>,
pub target_date: MaybeUndefined<NullableDateComparator>,
pub health: MaybeUndefined<StringComparator>,
pub health_with_age: MaybeUndefined<StringComparator>,
pub activity_type: MaybeUndefined<StringComparator>,
pub has_related_relations: MaybeUndefined<RelationExistsComparator>,
pub has_depended_on_by_relations: MaybeUndefined<RelationExistsComparator>,
pub has_depends_on_relations: MaybeUndefined<RelationExistsComparator>,
pub has_blocked_by_relations: MaybeUndefined<RelationExistsComparator>,
pub has_blocking_relations: MaybeUndefined<RelationExistsComparator>,
pub has_violated_relations: MaybeUndefined<RelationExistsComparator>,
pub project_updates: MaybeUndefined<ProjectUpdatesCollectionFilter>,
pub creator: MaybeUndefined<Box<UserFilter>>,
pub lead: MaybeUndefined<Box<NullableUserFilter>>,
pub members: MaybeUndefined<Box<UserCollectionFilter>>,
pub issues: MaybeUndefined<Box<IssueCollectionFilter>>,
pub roadmaps: MaybeUndefined<Box<RoadmapCollectionFilter>>,
pub initiatives: MaybeUndefined<Box<InitiativeCollectionFilter>>,
pub project_milestones: MaybeUndefined<Box<ProjectMilestoneCollectionFilter>>,
pub completed_project_milestones: MaybeUndefined<Box<ProjectMilestoneCollectionFilter>>,
pub next_project_milestone: MaybeUndefined<Box<ProjectMilestoneFilter>>,
pub accessible_teams: MaybeUndefined<Box<TeamCollectionFilter>>,
pub last_applied_template: MaybeUndefined<NullableTemplateFilter>,
pub needs: MaybeUndefined<Box<CustomerNeedCollectionFilter>>,
pub customer_count: MaybeUndefined<NumberComparator>,
pub customer_important_count: MaybeUndefined<NumberComparator>,
pub and: MaybeUndefined<Vec<ProjectCollectionFilter>>,
pub or: MaybeUndefined<Vec<ProjectCollectionFilter>>,
pub some: MaybeUndefined<Box<ProjectFilter>>,
pub every: MaybeUndefined<Box<ProjectFilter>>,
pub length: MaybeUndefined<NumberComparator>,
}Expand description
Project filtering options.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
name: MaybeUndefined<StringComparator>Comparator for the project name.
slug_id: MaybeUndefined<StringComparator>Comparator for the project slug ID.
state: MaybeUndefined<StringComparator>DEPRECATED Comparator for the project state.
status: MaybeUndefined<Box<ProjectStatusFilter>>Filters that the project’s status must satisfy.
priority: MaybeUndefined<NullableNumberComparator>Comparator for the projects priority.
labels: MaybeUndefined<Box<ProjectLabelCollectionFilter>>Filters that project labels must satisfy.
searchable_content: MaybeUndefined<ContentComparator>Internal Comparator for the project’s content.
started_at: MaybeUndefined<NullableDateComparator>Comparator for the project started date (when it was moved to an “In Progress” status).
completed_at: MaybeUndefined<NullableDateComparator>Comparator for the project completion date.
canceled_at: MaybeUndefined<NullableDateComparator>Comparator for the project cancelation date.
start_date: MaybeUndefined<NullableDateComparator>Comparator for the project start date.
target_date: MaybeUndefined<NullableDateComparator>Comparator for the project target date.
health: MaybeUndefined<StringComparator>Comparator for the project health: onTrack, atRisk, offTrack
health_with_age: MaybeUndefined<StringComparator>Comparator for the project health (with age): onTrack, atRisk, offTrack, outdated, noUpdate
activity_type: MaybeUndefined<StringComparator>ALPHA Comparator for the project activity type: buzzin, active, some, none
Comparator for filtering projects with relations.
has_depended_on_by_relations: MaybeUndefined<RelationExistsComparator>Deprecated Comparator for filtering projects which this is depended on by.
has_depends_on_relations: MaybeUndefined<RelationExistsComparator>DeprecatedComparator for filtering projects which this depends on.
has_blocked_by_relations: MaybeUndefined<RelationExistsComparator>Comparator for filtering projects which are blocked.
has_blocking_relations: MaybeUndefined<RelationExistsComparator>Comparator for filtering projects which are blocking.
has_violated_relations: MaybeUndefined<RelationExistsComparator>Comparator for filtering projects with violated dependencies.
project_updates: MaybeUndefined<ProjectUpdatesCollectionFilter>Comparator for the project updates.
creator: MaybeUndefined<Box<UserFilter>>Filters that the projects creator must satisfy.
lead: MaybeUndefined<Box<NullableUserFilter>>Filters that the projects lead must satisfy.
members: MaybeUndefined<Box<UserCollectionFilter>>Filters that the projects members must satisfy.
issues: MaybeUndefined<Box<IssueCollectionFilter>>Filters that the projects issues must satisfy.
roadmaps: MaybeUndefined<Box<RoadmapCollectionFilter>>Filters that the projects roadmaps must satisfy.
initiatives: MaybeUndefined<Box<InitiativeCollectionFilter>>Filters that the projects initiatives must satisfy.
project_milestones: MaybeUndefined<Box<ProjectMilestoneCollectionFilter>>Filters that the project’s milestones must satisfy.
completed_project_milestones: MaybeUndefined<Box<ProjectMilestoneCollectionFilter>>Filters that the project’s completed milestones must satisfy.
next_project_milestone: MaybeUndefined<Box<ProjectMilestoneFilter>>Filters that the project’s next milestone must satisfy.
accessible_teams: MaybeUndefined<Box<TeamCollectionFilter>>Filters that the project’s team must satisfy.
last_applied_template: MaybeUndefined<NullableTemplateFilter>Filters that the last applied template must satisfy.
needs: MaybeUndefined<Box<CustomerNeedCollectionFilter>>Filters that the project’s customer needs must satisfy.
customer_count: MaybeUndefined<NumberComparator>Count of customers
customer_important_count: MaybeUndefined<NumberComparator>Count of important customers
and: MaybeUndefined<Vec<ProjectCollectionFilter>>Compound filters, all of which need to be matched by the project.
or: MaybeUndefined<Vec<ProjectCollectionFilter>>Compound filters, one of which need to be matched by the project.
some: MaybeUndefined<Box<ProjectFilter>>Filters that needs to be matched by some projects.
every: MaybeUndefined<Box<ProjectFilter>>Filters that needs to be matched by all projects.
length: MaybeUndefined<NumberComparator>Comparator for the collection length.