pub struct ProjectCreateInput {Show 22 fields
pub id: MaybeUndefined<String>,
pub name: String,
pub icon: MaybeUndefined<String>,
pub color: MaybeUndefined<String>,
pub status_id: MaybeUndefined<String>,
pub description: MaybeUndefined<String>,
pub content: MaybeUndefined<String>,
pub team_ids: Vec<String>,
pub converted_from_issue_id: MaybeUndefined<String>,
pub last_applied_template_id: MaybeUndefined<String>,
pub template_id: MaybeUndefined<String>,
pub use_default_template: MaybeUndefined<bool>,
pub lead_id: MaybeUndefined<String>,
pub member_ids: MaybeUndefined<Vec<String>>,
pub start_date: MaybeUndefined<NaiveDate>,
pub start_date_resolution: MaybeUndefined<DateResolutionType>,
pub target_date: MaybeUndefined<NaiveDate>,
pub target_date_resolution: MaybeUndefined<DateResolutionType>,
pub sort_order: MaybeUndefined<f64>,
pub priority_sort_order: MaybeUndefined<f64>,
pub priority: MaybeUndefined<i64>,
pub label_ids: MaybeUndefined<Vec<String>>,
}Expand description
Input for creating a new project. A name and at least one team are required. All other fields are optional and will use defaults if not specified.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
name: StringThe name of the project.
icon: MaybeUndefined<String>The icon of the project.
color: MaybeUndefined<String>The color of the project.
status_id: MaybeUndefined<String>The ID of the project status.
description: MaybeUndefined<String>The description for the project.
content: MaybeUndefined<String>The project content as markdown.
team_ids: Vec<String>The identifiers of the teams this project is associated with.
converted_from_issue_id: MaybeUndefined<String>The ID of the issue that was converted into this project.
last_applied_template_id: MaybeUndefined<String>The ID of the last template applied to the project.
template_id: MaybeUndefined<String>The ID of a project template to apply when creating the project. Overrides useDefaultTemplate if both are provided.
use_default_template: MaybeUndefined<bool>When set to true, the default project template of the first team provided will be applied. If templateId is provided, this will be ignored.
lead_id: MaybeUndefined<String>The identifier of the project lead.
member_ids: MaybeUndefined<Vec<String>>The identifiers of the members of this project.
start_date: MaybeUndefined<NaiveDate>The planned start date of the project.
start_date_resolution: MaybeUndefined<DateResolutionType>The resolution of the project’s start date.
target_date: MaybeUndefined<NaiveDate>The planned target date of the project.
target_date_resolution: MaybeUndefined<DateResolutionType>The resolution of the project’s estimated completion date.
sort_order: MaybeUndefined<f64>The sort order for the project within shared views.
priority_sort_order: MaybeUndefined<f64>The sort order for the project within shared views, when ordered by priority.
priority: MaybeUndefined<i64>The priority of the project. 0 = No priority, 1 = Urgent, 2 = High, 3 = Medium, 4 = Low.
label_ids: MaybeUndefined<Vec<String>>Internal The identifiers of the project labels associated with this project.