pub struct ProjectUpdateInput {Show 31 fields
pub status_id: MaybeUndefined<String>,
pub name: MaybeUndefined<String>,
pub description: MaybeUndefined<String>,
pub content: MaybeUndefined<String>,
pub converted_from_issue_id: MaybeUndefined<String>,
pub last_applied_template_id: MaybeUndefined<String>,
pub icon: MaybeUndefined<String>,
pub color: MaybeUndefined<String>,
pub team_ids: MaybeUndefined<Vec<String>>,
pub project_update_reminders_paused_until_at: MaybeUndefined<DateTime<Utc>>,
pub update_reminder_frequency_in_weeks: MaybeUndefined<f64>,
pub update_reminder_frequency: MaybeUndefined<f64>,
pub frequency_resolution: MaybeUndefined<FrequencyResolutionType>,
pub update_reminders_day: MaybeUndefined<Day>,
pub update_reminders_hour: MaybeUndefined<i64>,
pub lead_id: MaybeUndefined<String>,
pub member_ids: MaybeUndefined<Vec<String>>,
pub start_date: MaybeUndefined<NaiveDate>,
pub start_date_resolution: MaybeUndefined<DateResolutionType>,
pub target_date: MaybeUndefined<NaiveDate>,
pub target_date_resolution: MaybeUndefined<DateResolutionType>,
pub completed_at: MaybeUndefined<DateTime<Utc>>,
pub canceled_at: MaybeUndefined<DateTime<Utc>>,
pub slack_new_issue: MaybeUndefined<bool>,
pub slack_issue_comments: MaybeUndefined<bool>,
pub slack_issue_statuses: MaybeUndefined<bool>,
pub sort_order: MaybeUndefined<f64>,
pub priority_sort_order: MaybeUndefined<f64>,
pub trashed: MaybeUndefined<bool>,
pub priority: MaybeUndefined<i64>,
pub label_ids: MaybeUndefined<Vec<String>>,
}Expand description
Input for updating an existing project. All fields are optional; only provided fields will be updated. Setting a field to null (where supported) will clear the value.
Fields
status_id: MaybeUndefined<String>The ID of the project status.
name: MaybeUndefined<String>The name of the project.
description: MaybeUndefined<String>The description for the project.
content: MaybeUndefined<String>The project content as markdown.
converted_from_issue_id: MaybeUndefined<String>The ID of the issue from which that project is created.
last_applied_template_id: MaybeUndefined<String>The ID of the last template applied to the project.
icon: MaybeUndefined<String>The icon of the project.
color: MaybeUndefined<String>The color of the project.
team_ids: MaybeUndefined<Vec<String>>The identifiers of the teams this project is associated with.
project_update_reminders_paused_until_at: MaybeUndefined<DateTime<Utc>>The time until which project update reminders are paused. Set to null to resume reminders.
update_reminder_frequency_in_weeks: MaybeUndefined<f64>The n-weekly frequency at which to prompt for project updates. When not set, reminders are inherited from workspace settings.
update_reminder_frequency: MaybeUndefined<f64>The frequency at which to prompt for project updates. When not set, reminders are inherited from workspace settings.
frequency_resolution: MaybeUndefined<FrequencyResolutionType>The resolution type for the update reminder frequency (e.g., weekly, biweekly).
update_reminders_day: MaybeUndefined<Day>The day of the week on which to prompt for project updates.
update_reminders_hour: MaybeUndefined<i64>The hour of the day (0-23) at which to prompt for project updates.
lead_id: MaybeUndefined<String>The identifier of the project lead.
member_ids: MaybeUndefined<Vec<String>>The identifiers of the members of this project.
start_date: MaybeUndefined<NaiveDate>The planned start date of the project.
start_date_resolution: MaybeUndefined<DateResolutionType>The resolution of the project’s start date.
target_date: MaybeUndefined<NaiveDate>The planned target date of the project.
target_date_resolution: MaybeUndefined<DateResolutionType>The resolution of the project’s estimated completion date.
completed_at: MaybeUndefined<DateTime<Utc>>The time at which the project was completed.
canceled_at: MaybeUndefined<DateTime<Utc>>The time at which the project was canceled.
slack_new_issue: MaybeUndefined<bool>Whether to send new issue notifications to Slack.
slack_issue_comments: MaybeUndefined<bool>Whether to send new issue comment notifications to Slack.
slack_issue_statuses: MaybeUndefined<bool>Whether to send issue status update notifications to Slack.
sort_order: MaybeUndefined<f64>The sort order for the project in shared views.
priority_sort_order: MaybeUndefined<f64>The sort order for the project within shared views, when ordered by priority.
trashed: MaybeUndefined<bool>Whether the project has been trashed. Set to true to trash, or null to restore.
priority: MaybeUndefined<i64>The priority of the project. 0 = No priority, 1 = Urgent, 2 = High, 3 = Medium, 4 = Low.
label_ids: MaybeUndefined<Vec<String>>The identifiers of the project labels associated with this project.