pub struct PushSubscriptionCreateInput {
pub id: MaybeUndefined<String>,
pub data: String,
pub type: MaybeUndefined<PushSubscriptionType>,
}Expand description
Input for creating a push subscription to receive push notifications on a device or browser.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
data: StringThe push subscription data in stringified JSON format. For web subscriptions, this must contain keys, endpoint, and expirationTime fields per the Web Push API specification. For mobile subscriptions, this contains the device token.
type: MaybeUndefined<PushSubscriptionType>The type of push subscription: ‘web’ for browser-based Web Push API, ‘apple’ for Apple Push Notification service (or ‘appleDevelopment’ for sandbox), or ‘firebase’ for Firebase Cloud Messaging (Android).