pub struct ReleasePipelineCollectionFilter {
pub id: MaybeUndefined<IDComparator>,
pub created_at: MaybeUndefined<DateComparator>,
pub updated_at: MaybeUndefined<DateComparator>,
pub name: MaybeUndefined<StringComparator>,
pub is_production: MaybeUndefined<BooleanComparator>,
pub teams: MaybeUndefined<Box<TeamCollectionFilter>>,
pub and: MaybeUndefined<Vec<ReleasePipelineCollectionFilter>>,
pub or: MaybeUndefined<Vec<ReleasePipelineCollectionFilter>>,
pub some: MaybeUndefined<Box<ReleasePipelineFilter>>,
pub every: MaybeUndefined<Box<ReleasePipelineFilter>>,
pub length: MaybeUndefined<NumberComparator>,
}Expand description
ALPHA Release pipeline collection filtering options.
Fields
id: MaybeUndefined<IDComparator>Comparator for the identifier.
created_at: MaybeUndefined<DateComparator>Comparator for the created at date.
updated_at: MaybeUndefined<DateComparator>Comparator for the updated at date.
name: MaybeUndefined<StringComparator>Comparator for the pipeline name.
is_production: MaybeUndefined<BooleanComparator>Comparator for the pipeline production flag.
teams: MaybeUndefined<Box<TeamCollectionFilter>>Filters that the release pipeline’s teams must satisfy.
and: MaybeUndefined<Vec<ReleasePipelineCollectionFilter>>Compound filters, all of which need to be matched by the release pipeline.
or: MaybeUndefined<Vec<ReleasePipelineCollectionFilter>>Compound filters, one of which need to be matched by the release pipeline.
some: MaybeUndefined<Box<ReleasePipelineFilter>>Filters that needs to be matched by some release pipelines.
every: MaybeUndefined<Box<ReleasePipelineFilter>>Filters that needs to be matched by all release pipelines.
length: MaybeUndefined<NumberComparator>Comparator for the collection length.