pub struct ReleasePipelineCreateInput {
pub id: MaybeUndefined<String>,
pub name: String,
pub slug_id: MaybeUndefined<String>,
pub type: MaybeUndefined<ReleasePipelineType>,
pub is_production: MaybeUndefined<bool>,
pub include_path_patterns: MaybeUndefined<Vec<String>>,
pub team_ids: MaybeUndefined<Vec<String>>,
}Expand description
Input for creating a new release pipeline.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
name: StringThe name of the pipeline.
slug_id: MaybeUndefined<String>The pipeline’s unique slug identifier. If not provided, it will be auto-generated.
type: MaybeUndefined<ReleasePipelineType>The type of the pipeline.
is_production: MaybeUndefined<bool>Whether this pipeline targets a production environment. Default to true.
include_path_patterns: MaybeUndefined<Vec<String>>Glob patterns to include commits affecting matching file paths.
team_ids: MaybeUndefined<Vec<String>>The identifiers of the teams this pipeline is associated with.