pub struct ReleaseStageCreateInput {
pub id: MaybeUndefined<String>,
pub name: String,
pub color: String,
pub type: ReleaseStageType,
pub position: f64,
pub pipeline_id: String,
pub frozen: MaybeUndefined<bool>,
}Expand description
Input for creating a new release stage.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
name: StringThe name of the stage.
color: StringThe UI color of the stage as a HEX string.
type: ReleaseStageTypeThe type of the stage.
position: f64The position of the stage.
pipeline_id: StringThe identifier of the pipeline this stage belongs to.
frozen: MaybeUndefined<bool>Whether this stage is frozen. Only applicable to started stages.