pub struct SlackChannelNameMappingInput {Show 14 fields
pub id: String,
pub name: String,
pub is_private: MaybeUndefined<bool>,
pub is_shared: MaybeUndefined<bool>,
pub bot_added: MaybeUndefined<bool>,
pub teams: Vec<SlackAsksTeamSettingsInput>,
pub auto_create_on_message: MaybeUndefined<bool>,
pub auto_create_on_emoji: MaybeUndefined<bool>,
pub auto_create_on_bot_mention: MaybeUndefined<bool>,
pub auto_create_template_id: MaybeUndefined<String>,
pub post_cancellation_updates: MaybeUndefined<bool>,
pub post_completion_updates: MaybeUndefined<bool>,
pub post_accepted_from_triage_updates: MaybeUndefined<bool>,
pub ai_titles: MaybeUndefined<bool>,
}Fields
id: StringThe Slack channel ID.
name: StringThe Slack channel name.
is_private: MaybeUndefined<bool>Whether or not the Slack channel is private.
Whether or not the Slack channel is shared with an external org.
bot_added: MaybeUndefined<bool>Whether or not the Linear Asks bot has been added to this Slack channel.
teams: Vec<SlackAsksTeamSettingsInput>Which teams are connected to the channel and settings for those teams.
auto_create_on_message: MaybeUndefined<bool>Whether or not top-level messages in this channel should automatically create Asks.
auto_create_on_emoji: MaybeUndefined<bool>Whether or not using the :ticket: emoji in this channel should automatically create Asks.
auto_create_on_bot_mention: MaybeUndefined<bool>Whether or not @-mentioning the bot should automatically create an Ask with the message.
auto_create_template_id: MaybeUndefined<String>The optional template ID to use for Asks auto-created in this channel. If not set, auto-created Asks won’t use any template.
post_cancellation_updates: MaybeUndefined<bool>Whether or not synced Slack threads should be updated with a message and emoji when their Ask is canceled.
post_completion_updates: MaybeUndefined<bool>Whether or not synced Slack threads should be updated with a message and emoji when their Ask is completed.
post_accepted_from_triage_updates: MaybeUndefined<bool>Whether or not synced Slack threads should be updated with a message when their Ask is accepted from triage.
ai_titles: MaybeUndefined<bool>Whether or not to use AI to generate titles for Asks created in this channel.