TeamUpdateInput

Struct TeamUpdateInput 

pub struct TeamUpdateInput {
Show 53 fields pub name: MaybeUndefined<String>, pub description: MaybeUndefined<String>, pub key: MaybeUndefined<String>, pub icon: MaybeUndefined<String>, pub color: MaybeUndefined<String>, pub cycles_enabled: MaybeUndefined<bool>, pub cycle_start_day: MaybeUndefined<f64>, pub cycle_duration: MaybeUndefined<i64>, pub cycle_cooldown_time: MaybeUndefined<i64>, pub cycle_issue_auto_assign_started: MaybeUndefined<bool>, pub cycle_issue_auto_assign_completed: MaybeUndefined<bool>, pub cycle_lock_to_active: MaybeUndefined<bool>, pub cycle_enabled_start_date: MaybeUndefined<DateTime<Utc>>, pub upcoming_cycle_count: MaybeUndefined<f64>, pub timezone: MaybeUndefined<String>, pub inherit_issue_estimation: MaybeUndefined<bool>, pub issue_estimation_type: MaybeUndefined<String>, pub issue_estimation_allow_zero: MaybeUndefined<bool>, pub set_issue_sort_order_on_state_change: MaybeUndefined<String>, pub issue_estimation_extended: MaybeUndefined<bool>, pub default_issue_estimate: MaybeUndefined<f64>, pub slack_new_issue: MaybeUndefined<bool>, pub slack_issue_comments: MaybeUndefined<bool>, pub slack_issue_statuses: MaybeUndefined<bool>, pub group_issue_history: MaybeUndefined<bool>, pub ai_thread_summaries_enabled: MaybeUndefined<bool>, pub ai_discussion_summaries_enabled: MaybeUndefined<bool>, pub default_template_for_members_id: MaybeUndefined<String>, pub default_template_for_non_members_id: MaybeUndefined<String>, pub default_project_template_id: MaybeUndefined<String>, pub private: MaybeUndefined<bool>, pub triage_enabled: MaybeUndefined<bool>, pub require_priority_to_leave_triage: MaybeUndefined<bool>, pub default_issue_state_id: MaybeUndefined<String>, pub auto_close_period: MaybeUndefined<f64>, pub auto_close_state_id: MaybeUndefined<String>, pub auto_close_parent_issues: MaybeUndefined<bool>, pub auto_close_child_issues: MaybeUndefined<bool>, pub auto_archive_period: MaybeUndefined<f64>, pub marked_as_duplicate_workflow_state_id: MaybeUndefined<String>, pub join_by_default: MaybeUndefined<bool>, pub scim_managed: MaybeUndefined<bool>, pub parent_id: MaybeUndefined<String>, pub inherit_workflow_statuses: MaybeUndefined<bool>, pub inherit_product_intelligence_scope: MaybeUndefined<bool>, pub product_intelligence_scope: MaybeUndefined<ProductIntelligenceScope>, pub issue_sharing_enabled: MaybeUndefined<bool>, pub inherit_slack_auto_create_project_channel: MaybeUndefined<bool>, pub slack_auto_create_project_channel: MaybeUndefined<bool>, pub security_settings: MaybeUndefined<TeamSecuritySettingsInput>, pub all_members_can_join: MaybeUndefined<bool>, pub retired_at: MaybeUndefined<DateTime<Utc>>, pub handle_sub_teams_on_retirement: MaybeUndefined<TeamRetirementSubTeamHandling>,
}

Fields

name: MaybeUndefined<String>

The name of the team.

description: MaybeUndefined<String>

The description of the team.

key: MaybeUndefined<String>

The key of the team.

icon: MaybeUndefined<String>

The icon of the team.

color: MaybeUndefined<String>

The color of the team.

cycles_enabled: MaybeUndefined<bool>

Whether the team uses cycles.

cycle_start_day: MaybeUndefined<f64>

The day of the week that a new cycle starts.

cycle_duration: MaybeUndefined<i64>

The duration of each cycle in weeks.

cycle_cooldown_time: MaybeUndefined<i64>

The cooldown time after each cycle in weeks.

cycle_issue_auto_assign_started: MaybeUndefined<bool>

Auto assign started issues to current active cycle setting.

cycle_issue_auto_assign_completed: MaybeUndefined<bool>

Auto assign completed issues to current active cycle setting.

cycle_lock_to_active: MaybeUndefined<bool>

Only allow issues with cycles in Active Issues.

cycle_enabled_start_date: MaybeUndefined<DateTime<Utc>>

The time at which to begin cycles.

upcoming_cycle_count: MaybeUndefined<f64>

How many upcoming cycles to create.

timezone: MaybeUndefined<String>

The timezone of the team.

inherit_issue_estimation: MaybeUndefined<bool>

Whether the team should inherit estimation settings from its parent. Only applies to sub-teams.

issue_estimation_type: MaybeUndefined<String>

The issue estimation type to use. Must be one of “notUsed”, “exponential”, “fibonacci”, “linear”, “tShirt”.

issue_estimation_allow_zero: MaybeUndefined<bool>

Whether to allow zeros in issues estimates.

set_issue_sort_order_on_state_change: MaybeUndefined<String>

Whether to move issues to bottom of the column when changing state.

issue_estimation_extended: MaybeUndefined<bool>

Whether to add additional points to the estimate scale.

default_issue_estimate: MaybeUndefined<f64>

What to use as an default estimate for unestimated issues.

slack_new_issue: MaybeUndefined<bool>

Whether to send new issue notifications to Slack.

slack_issue_comments: MaybeUndefined<bool>

Whether to send new issue comment notifications to Slack.

slack_issue_statuses: MaybeUndefined<bool>

Whether to send issue status update notifications to Slack.

group_issue_history: MaybeUndefined<bool>

Whether to group recent issue history entries.

ai_thread_summaries_enabled: MaybeUndefined<bool>

Whether to enable resolved thread AI summaries.

ai_discussion_summaries_enabled: MaybeUndefined<bool>

Whether to enable AI discussion summaries for issues.

default_template_for_members_id: MaybeUndefined<String>

The identifier of the default template for members of this team.

default_template_for_non_members_id: MaybeUndefined<String>

The identifier of the default template for non-members of this team.

default_project_template_id: MaybeUndefined<String>

The identifier of the default project template of this team.

private: MaybeUndefined<bool>

Whether the team is private or not.

triage_enabled: MaybeUndefined<bool>

Whether triage mode is enabled for the team.

require_priority_to_leave_triage: MaybeUndefined<bool>

Whether an issue needs to have a priority set before leaving triage.

default_issue_state_id: MaybeUndefined<String>

Default status for newly created issues.

auto_close_period: MaybeUndefined<f64>

Period after which issues are automatically closed, in months.

auto_close_state_id: MaybeUndefined<String>

The canceled workflow state which auto closed issues will be set to.

auto_close_parent_issues: MaybeUndefined<bool>

Whether to automatically close a parent issue in this team if all its sub-issues are closed.

auto_close_child_issues: MaybeUndefined<bool>

Whether to automatically close all sub-issues when a parent issue in this team is closed.

auto_archive_period: MaybeUndefined<f64>

Period after which closed (completed, canceled, or duplicate) issues are automatically archived, in months.

marked_as_duplicate_workflow_state_id: MaybeUndefined<String>

The workflow state into which issues are moved when they are marked as a duplicate of another issue.

join_by_default: MaybeUndefined<bool>

Whether new users should join this team by default. Mutation restricted to workspace admins or owners!

scim_managed: MaybeUndefined<bool>

Whether the team is managed by SCIM integration. Mutation restricted to workspace admins or owners and only unsetting is allowed!

parent_id: MaybeUndefined<String>

The parent team ID.

inherit_workflow_statuses: MaybeUndefined<bool>

Internal Whether the team should inherit workflow statuses from its parent.

inherit_product_intelligence_scope: MaybeUndefined<bool>

Internal Whether the team should inherit its product intelligence scope from its parent. Only applies to sub-teams.

product_intelligence_scope: MaybeUndefined<ProductIntelligenceScope>

Internal The scope of product intelligence suggestion data for the team.

issue_sharing_enabled: MaybeUndefined<bool>

Whether issue sharing is enabled for this team.

inherit_slack_auto_create_project_channel: MaybeUndefined<bool>

Internal Whether the team should inherit its Slack auto-create project channel setting from its parent. Only applies to sub-teams.

slack_auto_create_project_channel: MaybeUndefined<bool>

Internal Whether to automatically create a Slack channel when a new project is created in this team.

security_settings: MaybeUndefined<TeamSecuritySettingsInput>

The security settings for the team.

all_members_can_join: MaybeUndefined<bool>

Whether all members in the workspace can join the team. Only used for public teams.

retired_at: MaybeUndefined<DateTime<Utc>>

When the team was retired.

handle_sub_teams_on_retirement: MaybeUndefined<TeamRetirementSubTeamHandling>

Internal How to handle sub-teams when retiring. Required if the team has active sub-teams.