pub struct ViewPreferencesCreateInput {Show 13 fields
pub id: MaybeUndefined<String>,
pub type: ViewPreferencesType,
pub view_type: ViewType,
pub preferences: Value,
pub insights: MaybeUndefined<Value>,
pub team_id: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub initiative_id: MaybeUndefined<String>,
pub label_id: MaybeUndefined<String>,
pub project_label_id: MaybeUndefined<String>,
pub release_pipeline_id: MaybeUndefined<String>,
pub custom_view_id: MaybeUndefined<String>,
pub user_id: MaybeUndefined<String>,
}Expand description
Input for creating view preferences.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
type: ViewPreferencesTypeThe type of view preferences (either user or workspace level preferences).
view_type: ViewTypeThe view type of the view preferences are associated with.
preferences: ValueView preferences object.
insights: MaybeUndefined<Value>The default parameters for the insight on that view.
team_id: MaybeUndefined<String>The team these view preferences are associated with.
project_id: MaybeUndefined<String>The project these view preferences are associated with.
initiative_id: MaybeUndefined<String>Internal The initiative these view preferences are associated with.
label_id: MaybeUndefined<String>The label these view preferences are associated with.
project_label_id: MaybeUndefined<String>The project label these view preferences are associated with.
release_pipeline_id: MaybeUndefined<String>The release pipeline these view preferences are associated with.
custom_view_id: MaybeUndefined<String>The custom view these view preferences are associated with.
user_id: MaybeUndefined<String>The user profile these view preferences are associated with.