pub struct ZendeskSettingsInput {Show 15 fields
pub send_note_on_status_change: MaybeUndefined<bool>,
pub send_note_on_comment: MaybeUndefined<bool>,
pub automate_ticket_reopening_on_completion: MaybeUndefined<bool>,
pub automate_ticket_reopening_on_cancellation: MaybeUndefined<bool>,
pub automate_ticket_reopening_on_comment: MaybeUndefined<bool>,
pub disable_customer_requests_auto_creation: MaybeUndefined<bool>,
pub automate_ticket_reopening_on_project_completion: MaybeUndefined<bool>,
pub automate_ticket_reopening_on_project_cancellation: MaybeUndefined<bool>,
pub enable_ai_intake: MaybeUndefined<bool>,
pub subdomain: String,
pub url: String,
pub bot_user_id: MaybeUndefined<String>,
pub can_read_customers: MaybeUndefined<bool>,
pub supports_o_auth_refresh: MaybeUndefined<bool>,
pub host_mappings: MaybeUndefined<Vec<String>>,
}Fields
send_note_on_status_change: MaybeUndefined<bool>Whether an internal message should be added when a Linear issue changes status (for status types except completed or canceled).
send_note_on_comment: MaybeUndefined<bool>Whether an internal message should be added when someone comments on an issue.
automate_ticket_reopening_on_completion: MaybeUndefined<bool>Whether a ticket should be automatically reopened when its linked Linear issue is completed.
automate_ticket_reopening_on_cancellation: MaybeUndefined<bool>Whether a ticket should be automatically reopened when its linked Linear issue is cancelled.
automate_ticket_reopening_on_comment: MaybeUndefined<bool>Whether a ticket should be automatically reopened when a comment is posted on its linked Linear issue
disable_customer_requests_auto_creation: MaybeUndefined<bool>ALPHA Whether customer and customer requests should not be automatically created when conversations are linked to a Linear issue.
automate_ticket_reopening_on_project_completion: MaybeUndefined<bool>Whether a ticket should be automatically reopened when its linked Linear project is completed.
automate_ticket_reopening_on_project_cancellation: MaybeUndefined<bool>Whether a ticket should be automatically reopened when its linked Linear project is cancelled.
enable_ai_intake: MaybeUndefined<bool>Whether Linear Agent should be enabled for this integration.
subdomain: StringThe subdomain of the Zendesk organization being connected.
url: StringThe URL of the connected Zendesk organization.
bot_user_id: MaybeUndefined<String>The ID of the Linear bot user.
can_read_customers: MaybeUndefined<bool>INTERNAL Temporary flag indicating if the integration has the necessary scopes for Customers
supports_o_auth_refresh: MaybeUndefined<bool>INTERNAL Flag indicating if the integration supports OAuth refresh tokens
host_mappings: MaybeUndefined<Vec<String>>The host mappings from Zendesk brands.