pub async fn project<T: DeserializeOwned + GraphQLFields<FullType = Project>>(
client: &Client,
id: String,
) -> Result<T, LinearError>Expand description
Returns a single project by its identifier or URL slug.
Full type: Project
pub async fn project<T: DeserializeOwned + GraphQLFields<FullType = Project>>(
client: &Client,
id: String,
) -> Result<T, LinearError>Returns a single project by its identifier or URL slug.
Full type: Project