pub struct AiConversationPartMetadata {
pub turn_id: Option<String>,
pub eval_log_id: Option<String>,
pub started_at: Option<String>,
pub ended_at: Option<String>,
pub phase: Option<AiConversationPartPhase>,
pub feedback: Option<Value>,
}Expand description
Metadata about a part in an AI conversation.
Fields
turn_id: Option<String>The turn ID of the part.
eval_log_id: Option<String>The eval log ID of the part.
started_at: Option<String>The time when the part started, as an ISO 8601 string.
ended_at: Option<String>The time when the part ended, as an ISO 8601 string.
phase: Option<AiConversationPartPhase>The phase during which the part was generated.
feedback: Option<Value>AI feedback state for this part.