AiPromptRules

Struct AiPromptRules 

pub struct AiPromptRules {
    pub id: Option<String>,
    pub created_at: Option<DateTime<Utc>>,
    pub updated_at: Option<DateTime<Utc>>,
    pub archived_at: Option<DateTime<Utc>>,
    pub updated_by: Option<Box<User>>,
}
Custom rules that guide AI behavior for a specific scope. Rules can be defined at the workspace level, team level, integration level, or user level, and are applied hierarchically (workspace rules first, then parent team rules, then team rules). Rules contain structured content that instructs the AI assistant on how to handle specific types of prompts, such as coding agent guidance or triage intelligence configuration.

Fields

id: Option<String>

The unique identifier of the entity.

created_at: Option<DateTime<Utc>>

The time at which the entity was created.

updated_at: Option<DateTime<Utc>>

The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.

archived_at: Option<DateTime<Utc>>

The time at which the entity was archived. Null if the entity has not been archived.

updated_by: Option<Box<User>>

The user who last updated the AI prompt rules.