pub struct AuthenticationSessionResponse {Show 20 fields
pub created_at: Option<DateTime<Utc>>,
pub id: Option<String>,
pub type: Option<AuthenticationSessionType>,
pub ip: Option<String>,
pub location_country: Option<String>,
pub location_country_code: Option<String>,
pub country_codes: Option<Vec<String>>,
pub location_region_code: Option<String>,
pub location_city: Option<String>,
pub user_agent: Option<String>,
pub browser_type: Option<String>,
pub service: Option<String>,
pub last_active_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub location: Option<String>,
pub operating_system: Option<String>,
pub client: Option<String>,
pub name: Option<String>,
pub detailed_name: Option<String>,
pub is_current_session: Option<bool>,
}Expand description
Information about an active authentication session, including the device, location, and timestamps for when it was created and last used.
Fields
created_at: Option<DateTime<Utc>>The time at which the entity was created.
id: Option<String>type: Option<AuthenticationSessionType>Type of application used to authenticate.
ip: Option<String>IP address.
location_country: Option<String>Location country name.
location_country_code: Option<String>Location country code.
country_codes: Option<Vec<String>>Country codes of all seen locations.
location_region_code: Option<String>Location region code.
location_city: Option<String>Location city name.
user_agent: Option<String>Session’s user-agent.
browser_type: Option<String>Used web browser.
service: Option<String>Service used for logging in.
last_active_at: Option<DateTime<Utc>>When was the session last seen
updated_at: Option<DateTime<Utc>>Date when the session was last updated.
location: Option<String>Human readable location
operating_system: Option<String>Operating system used for the session
client: Option<String>Client used for the session
name: Option<String>Name of the session, derived from the client and operating system
detailed_name: Option<String>Detailed name of the session including version information, derived from the user agent.
is_current_session: Option<bool>Whether this session is the one used to make the current API request.