pub struct CustomerNeedNotification {Show 31 fields
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub type: Option<String>,
pub actor: Option<User>,
pub external_user_actor: Option<ExternalUser>,
pub user: Option<User>,
pub read_at: Option<DateTime<Utc>>,
pub emailed_at: Option<DateTime<Utc>>,
pub snoozed_until_at: Option<DateTime<Utc>>,
pub unsnoozed_at: Option<DateTime<Utc>>,
pub category: Option<NotificationCategory>,
pub url: Option<String>,
pub inbox_url: Option<String>,
pub title: Option<String>,
pub subtitle: Option<String>,
pub is_linear_actor: Option<bool>,
pub actor_avatar_url: Option<String>,
pub actor_initials: Option<String>,
pub actor_avatar_color: Option<String>,
pub issue_status_type: Option<String>,
pub project_update_health: Option<String>,
pub initiative_update_health: Option<String>,
pub grouping_key: Option<String>,
pub grouping_priority: Option<f64>,
pub bot_actor: Option<ActorBot>,
pub customer_need_id: Option<String>,
pub related_issue: Option<Issue>,
pub related_project: Option<Project>,
pub customer_need: Option<CustomerNeed>,
}Expand description
A notification related to a customer need (request), such as creation, resolution, or being marked as important.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
type: Option<String>Notification type. Determines the kind of event that triggered this notification and which associated entity fields will be populated.
actor: Option<User>The user that caused the notification. Null if the notification was triggered by a non-user actor such as an integration, external user, or system event.
external_user_actor: Option<ExternalUser>The external user that caused the notification. Populated when the notification was triggered by an external user (e.g., a commenter from a connected integration like Slack or GitHub) rather than a Linear workspace member.
user: Option<User>The recipient user of this notification.
read_at: Option<DateTime<Utc>>The time at which the user marked the notification as read. Null if the notification is unread.
emailed_at: Option<DateTime<Utc>>The time at which an email reminder for this notification was sent to the user. Null if no email reminder has been sent.
snoozed_until_at: Option<DateTime<Utc>>The time until which a notification is snoozed. After this time, the notification reappears in the user’s inbox. Null if the notification is not currently snoozed.
unsnoozed_at: Option<DateTime<Utc>>The time at which a notification was unsnoozed. Null if the notification has not been unsnoozed.
category: Option<NotificationCategory>The category of the notification.
url: Option<String>Internal URL to the target of the notification.
inbox_url: Option<String>Internal Inbox URL for the notification.
title: Option<String>Internal Notification title.
subtitle: Option<String>Internal Notification subtitle.
is_linear_actor: Option<bool>Internal If notification actor was Linear.
actor_avatar_url: Option<String>Internal Notification avatar URL.
actor_initials: Option<String>Internal Notification actor initials if avatar is not available.
actor_avatar_color: Option<String>Internal Notification actor initials if avatar is not available.
issue_status_type: Option<String>Internal Issue’s status type for issue notifications.
project_update_health: Option<String>Internal Project update health for new updates.
initiative_update_health: Option<String>Internal Initiative update health for new updates.
grouping_key: Option<String>Internal Notifications with the same grouping key will be grouped together in the UI.
grouping_priority: Option<f64>Internal Priority of the notification with the same grouping key. Higher number means higher priority. If priority is the same, notifications should be sorted by createdAt.
bot_actor: Option<ActorBot>The bot that caused the notification.
customer_need_id: Option<String>Related customer need.
The issue related to the notification.
The project related to the notification.
customer_need: Option<CustomerNeed>The customer need related to the notification.