pub struct CustomerNotificationSubscription {Show 17 fields
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub subscriber: Option<User>,
pub customer: Option<Customer>,
pub custom_view: Option<CustomView>,
pub cycle: Option<Cycle>,
pub label: Option<IssueLabel>,
pub project: Option<Project>,
pub initiative: Option<Initiative>,
pub team: Option<Team>,
pub user: Option<User>,
pub context_view_type: Option<ContextViewType>,
pub user_context_view_type: Option<UserContextViewType>,
pub active: Option<bool>,
pub notification_subscription_types: Option<Vec<String>>,
}Expand description
A notification subscription scoped to a specific customer. The subscriber receives notifications for events related to this customer, such as new customer needs or ownership changes.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
subscriber: Option<User>The user who will receive notifications from this subscription.
customer: Option<Customer>The customer subscribed to.
custom_view: Option<CustomView>The custom view that this notification subscription is scoped to. Null if the subscription targets a different entity type.
cycle: Option<Cycle>The cycle that this notification subscription is scoped to. Null if the subscription targets a different entity type.
label: Option<IssueLabel>The issue label that this notification subscription is scoped to. Null if the subscription targets a different entity type.
project: Option<Project>The project that this notification subscription is scoped to. Null if the subscription targets a different entity type.
initiative: Option<Initiative>The initiative that this notification subscription is scoped to. Null if the subscription targets a different entity type.
team: Option<Team>The team that this notification subscription is scoped to. Null if the subscription targets a different entity type.
user: Option<User>The user that this notification subscription is scoped to, for user-specific view subscriptions. Null if the subscription targets a different entity type.
context_view_type: Option<ContextViewType>The type of contextual view (e.g., active issues, backlog) that further scopes a team notification subscription. Null if the subscription is not associated with a specific view type.
user_context_view_type: Option<UserContextViewType>The type of user-specific view that further scopes a user notification subscription. Null if the subscription is not associated with a user view type.
active: Option<bool>Whether the subscription is active. When inactive, no notifications are generated from this subscription even though it still exists.
notification_subscription_types: Option<Vec<String>>The notification event types that this subscription will deliver to the subscriber.