pub struct DocumentContentHistoryType {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub content_data_snapshot_at: Option<DateTime<Utc>>,
pub content_data: Option<Value>,
pub actor_ids: Option<Vec<String>>,
pub metadata: Option<Value>,
}Fields
id: Option<String>The unique identifier of the document content history entry.
created_at: Option<DateTime<Utc>>The date when this document content history entry record was created.
content_data_snapshot_at: Option<DateTime<Utc>>The timestamp of the document content state when this snapshot was captured. This can differ from createdAt because the content is captured from its state at the previously known updatedAt timestamp in the case of an update. On document creation, these timestamps can be identical.
content_data: Option<Value>Internal The document content as a ProseMirror document at the time this history entry was captured.
actor_ids: Option<Vec<String>>IDs of users whose edits are included in this history entry.
metadata: Option<Value>Metadata associated with the history entry, including content diffs and AI-generated change summaries.