pub struct EmailIntakeAddress {Show 24 fields
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub address: Option<String>,
pub type: Option<EmailIntakeAddressType>,
pub forwarding_email_address: Option<String>,
pub sender_name: Option<String>,
pub enabled: Option<bool>,
pub replies_enabled: Option<bool>,
pub use_user_names_in_replies: Option<bool>,
pub template: Option<Template>,
pub team: Option<Team>,
pub organization: Option<Organization>,
pub ses_domain_identity: Option<SesDomainIdentity>,
pub creator: Option<User>,
pub customer_requests_enabled: Option<bool>,
pub issue_created_auto_reply: Option<String>,
pub issue_created_auto_reply_enabled: Option<bool>,
pub issue_completed_auto_reply_enabled: Option<bool>,
pub issue_completed_auto_reply: Option<String>,
pub issue_canceled_auto_reply_enabled: Option<bool>,
pub issue_canceled_auto_reply: Option<String>,
pub reopen_on_reply: Option<bool>,
}Expand description
An email address that creates Linear issues when emails are sent to it. Email intake addresses can be scoped to a specific team or issue template, and support configurable auto-reply messages for issue creation, completion, and cancellation events. They can also be configured for the Asks web form feature, enabling external users to submit requests via email.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
address: Option<String>The unique local part (before the @) of the intake email address, used to route incoming emails to the correct intake handler.
type: Option<EmailIntakeAddressType>The type of the email address.
forwarding_email_address: Option<String>The email address used to forward emails to the intake address.
sender_name: Option<String>The name to be used for outgoing emails.
enabled: Option<bool>Whether the email address is enabled.
replies_enabled: Option<bool>Whether email replies are enabled.
use_user_names_in_replies: Option<bool>Whether the commenter’s name is included in the email replies.
template: Option<Template>The template that the email address is associated with.
team: Option<Team>The team that the email address is associated with.
organization: Option<Organization>The workspace that the email address is associated with.
ses_domain_identity: Option<SesDomainIdentity>The SES domain identity that the email address is associated with.
creator: Option<User>The user who created the email intake address.
customer_requests_enabled: Option<bool>Whether issues created from emails sent to this address are automatically converted into customer requests, linking the sender as a customer contact.
issue_created_auto_reply: Option<String>The auto-reply message for issue created. If not set, the default reply will be used.
issue_created_auto_reply_enabled: Option<bool>Whether the auto-reply for issue created is enabled.
issue_completed_auto_reply_enabled: Option<bool>Whether the auto-reply for issue completed is enabled.
issue_completed_auto_reply: Option<String>The auto-reply message for issue completed. If not set, the default reply will be used.
issue_canceled_auto_reply_enabled: Option<bool>Whether the auto-reply for issue canceled is enabled.
issue_canceled_auto_reply: Option<String>The auto-reply message for issue canceled. If not set, the default reply will be used.
reopen_on_reply: Option<bool>Whether to reopen completed or canceled issues when a substantive email reply is received.