pub struct Emoji {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub name: Option<String>,
pub url: Option<String>,
pub source: Option<String>,
pub creator: Option<User>,
pub organization: Option<Organization>,
}Expand description
A custom emoji defined in the workspace. Custom emojis are uploaded by users and can be used in reactions and other places where standard emojis are supported. Each emoji has a unique name within the workspace.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
name: Option<String>The unique name of the custom emoji within the workspace.
url: Option<String>The URL of the uploaded image for this custom emoji.
source: Option<String>The source of the emoji, indicating how it was created (e.g., uploaded by a user or imported).
creator: Option<User>The user who created the emoji.
organization: Option<Organization>The workspace that the emoji belongs to.