Favorite

Struct Favorite 

pub struct Favorite {
Show 35 fields pub id: Option<String>, pub created_at: Option<DateTime<Utc>>, pub updated_at: Option<DateTime<Utc>>, pub archived_at: Option<DateTime<Utc>>, pub type: Option<String>, pub parent: Option<Box<Favorite>>, pub folder_name: Option<String>, pub project_tab: Option<ProjectTab>, pub predefined_view_type: Option<String>, pub initiative_tab: Option<InitiativeTab>, pub owner: Option<Box<User>>, pub sort_order: Option<f64>, pub children: Option<FavoriteConnection>, pub issue: Option<Box<Issue>>, pub project: Option<Box<Project>>, pub facet: Option<Box<Facet>>, pub project_team: Option<Box<Team>>, pub cycle: Option<Box<Cycle>>, pub custom_view: Option<Box<CustomView>>, pub predefined_view_team: Option<Box<Team>>, pub document: Option<Box<Document>>, pub initiative: Option<Box<Initiative>>, pub label: Option<Box<IssueLabel>>, pub project_label: Option<Box<ProjectLabel>>, pub user: Option<Box<User>>, pub customer: Option<Box<Customer>>, pub dashboard: Option<Box<Dashboard>>, pub pull_request: Option<Box<PullRequest>>, pub release: Option<Box<Release>>, pub release_pipeline: Option<ReleasePipeline>, pub url: Option<String>, pub title: Option<String>, pub detail: Option<String>, pub color: Option<String>, pub icon: Option<String>,
}
A user’s bookmarked item that appears in their sidebar for quick access. Favorites can reference various entity types including issues, projects, cycles, views, documents, initiatives, labels, users, customers, dashboards, and pull requests. Favorites can be organized into folders and ordered by the user. Each favorite is owned by a single user and links to exactly one target entity (or is a folder containing other favorites).

Fields

id: Option<String>

The unique identifier of the entity.

created_at: Option<DateTime<Utc>>

The time at which the entity was created.

updated_at: Option<DateTime<Utc>>

The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.

archived_at: Option<DateTime<Utc>>

The time at which the entity was archived. Null if the entity has not been archived.

type: Option<String>

The type of entity this favorite references, such as ‘issue’, ‘project’, ‘cycle’, ‘customView’, ‘document’, ‘folder’, etc. Determines which associated entity field is populated.

parent: Option<Box<Favorite>>

The parent folder of the favorite. Null if the favorite is at the top level of the sidebar. Only favorites of type ‘folder’ can be parents.

folder_name: Option<String>

The name of the folder. Only applies to favorites of type folder.

project_tab: Option<ProjectTab>

The targeted tab of the project.

predefined_view_type: Option<String>

The type of favorited predefined view (e.g., ‘allIssues’, ‘activeCycle’, ‘backlog’, ‘triage’). Only populated when the favorite type is ‘predefinedView’.

initiative_tab: Option<InitiativeTab>

The targeted tab of the initiative.

owner: Option<Box<User>>

The user who owns this favorite. Favorites are personal and only visible to their owner.

sort_order: Option<f64>

The position of this item in the user’s favorites list. Lower values appear first. Used to maintain user-defined ordering within the sidebar.

children: Option<FavoriteConnection>

Children of the favorite. Only applies to favorites of type folder.

issue: Option<Box<Issue>>

The favorited issue.

project: Option<Box<Project>>

The favorited project.

facet: Option<Box<Facet>>

INTERNAL The favorited facet.

project_team: Option<Box<Team>>

DEPRECATED The favorited team of the project.

cycle: Option<Box<Cycle>>

The favorited cycle.

custom_view: Option<Box<CustomView>>

The favorited custom view.

predefined_view_team: Option<Box<Team>>

The team of the favorited predefined view.

document: Option<Box<Document>>

The favorited document.

initiative: Option<Box<Initiative>>

The favorited initiative.

label: Option<Box<IssueLabel>>

The favorited label.

project_label: Option<Box<ProjectLabel>>

The favorited project label.

user: Option<Box<User>>

The favorited user.

customer: Option<Box<Customer>>

The favorited customer.

dashboard: Option<Box<Dashboard>>

The favorited dashboard.

pull_request: Option<Box<PullRequest>>

The favorited pull request.

release: Option<Box<Release>>

ALPHA The favorited release.

release_pipeline: Option<ReleasePipeline>

ALPHA The favorited release pipeline.

url: Option<String>

URL of the favorited entity. Folders return ‘null’ value.

title: Option<String>

Internal Favorite’s title text (name of the favorite’d object or folder).

detail: Option<String>

Internal Detail text for favorite’s title (e.g. team’s name for a project).

color: Option<String>

Internal Returns the color of the favorite’s icon. Unavailable for avatars and views with fixed icons (e.g. cycle).

icon: Option<String>

Internal Name of the favorite’s icon. Unavailable for standard views, issues, and avatars