pub struct InitiativeRelation {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub initiative: Option<Initiative>,
pub related_initiative: Option<Initiative>,
pub user: Option<User>,
pub sort_order: Option<f64>,
}Expand description
A parent-child relation between two initiatives, forming a hierarchy. The initiative field is the parent and relatedInitiative is the child. Cycles and excessive nesting depth are prevented.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
initiative: Option<Initiative>The parent initiative in this hierarchical relation.
The child initiative in this hierarchical relation.
user: Option<User>The user who last created or modified the relation. Null if the user has been deleted.
sort_order: Option<f64>The sort order of the child initiative within its parent initiative.