IssueHistory

Struct IssueHistory 

pub struct IssueHistory {
Show 80 fields pub id: Option<String>, pub created_at: Option<DateTime<Utc>>, pub updated_at: Option<DateTime<Utc>>, pub archived_at: Option<DateTime<Utc>>, pub issue: Option<Issue>, pub actor_id: Option<String>, pub updated_description: Option<bool>, pub from_title: Option<String>, pub to_title: Option<String>, pub from_assignee_id: Option<String>, pub to_assignee_id: Option<String>, pub from_priority: Option<f64>, pub to_priority: Option<f64>, pub from_team_id: Option<String>, pub to_team_id: Option<String>, pub from_parent_id: Option<String>, pub to_parent_id: Option<String>, pub from_state_id: Option<String>, pub to_state_id: Option<String>, pub from_cycle_id: Option<String>, pub to_cycle_id: Option<String>, pub to_converted_project_id: Option<String>, pub from_project_id: Option<String>, pub to_project_id: Option<String>, pub from_estimate: Option<f64>, pub to_estimate: Option<f64>, pub archived: Option<bool>, pub trashed: Option<bool>, pub attachment_id: Option<String>, pub added_label_ids: Option<Vec<String>>, pub removed_label_ids: Option<Vec<String>>, pub added_to_release_ids: Option<Vec<String>>, pub removed_from_release_ids: Option<Vec<String>>, pub relation_changes: Option<Vec<IssueRelationHistoryPayload>>, pub auto_closed: Option<bool>, pub auto_archived: Option<bool>, pub from_due_date: Option<NaiveDate>, pub to_due_date: Option<NaiveDate>, pub customer_need_id: Option<String>, pub changes: Option<Value>, pub actor: Option<User>, pub actors: Option<Vec<User>>, pub description_updated_by: Option<Vec<User>>, pub from_assignee: Option<User>, pub to_assignee: Option<User>, pub from_cycle: Option<Cycle>, pub to_cycle: Option<Cycle>, pub to_converted_project: Option<Project>, pub from_delegate: Option<User>, pub to_delegate: Option<User>, pub from_project: Option<Project>, pub to_project: Option<Project>, pub from_state: Option<WorkflowState>, pub to_state: Option<WorkflowState>, pub from_team: Option<Team>, pub to_team: Option<Team>, pub from_parent: Option<Issue>, pub to_parent: Option<Issue>, pub attachment: Option<Attachment>, pub issue_import: Option<IssueImport>, pub triage_responsibility_notified_users: Option<Vec<User>>, pub triage_responsibility_auto_assigned: Option<bool>, pub triage_responsibility_team: Option<Team>, pub from_project_milestone: Option<ProjectMilestone>, pub to_project_milestone: Option<ProjectMilestone>, pub from_sla_started_at: Option<DateTime<Utc>>, pub to_sla_started_at: Option<DateTime<Utc>>, pub from_sla_breaches_at: Option<DateTime<Utc>>, pub to_sla_breaches_at: Option<DateTime<Utc>>, pub from_sla_breached: Option<bool>, pub to_sla_breached: Option<bool>, pub from_sla_type: Option<String>, pub to_sla_type: Option<String>, pub bot_actor: Option<ActorBot>, pub added_labels: Option<Vec<IssueLabel>>, pub removed_labels: Option<Vec<IssueLabel>>, pub added_to_releases: Option<Vec<Release>>, pub removed_from_releases: Option<Vec<Release>>, pub triage_rule_metadata: Option<IssueHistoryTriageRuleMetadata>, pub workflow_metadata: Option<IssueHistoryWorkflowMetadata>,
}
A record of changes to an issue. Each history entry captures one or more property changes made to an issue within a short grouping window by the same actor. History entries track changes to fields such as title, assignee, status, priority, project, cycle, labels, due date, estimate, parent issue, and more. They also record metadata about what triggered the change (e.g., a user action, workflow automation, triage rule, or integration).

Fields

id: Option<String>

The unique identifier of the entity.

created_at: Option<DateTime<Utc>>

The time at which the entity was created.

updated_at: Option<DateTime<Utc>>

The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.

archived_at: Option<DateTime<Utc>>

The time at which the entity was archived. Null if the entity has not been archived.

issue: Option<Issue>

The issue that was changed.

actor_id: Option<String>

Identifier of the user who made these changes. Can be used to query the user directly. Null if the change was made by an integration, automation, or system process.

updated_description: Option<bool>

Whether the issue’s description was updated.

from_title: Option<String>

What the title was changed from.

to_title: Option<String>

What the title was changed to.

from_assignee_id: Option<String>

Identifier of the user from whom the issue was re-assigned. Can be used to query the user directly. Null if the assignee was not changed or the issue was previously unassigned.

to_assignee_id: Option<String>

Identifier of the user to whom the issue was assigned. Can be used to query the user directly. Null if the assignee was not changed or the issue was unassigned.

from_priority: Option<f64>

What the priority was changed from.

to_priority: Option<f64>

What the priority was changed to.

from_team_id: Option<String>

Identifier of the team from which the issue was moved. Can be used to query the team directly. Null if the team was not changed.

to_team_id: Option<String>

Identifier of the team to which the issue was moved. Can be used to query the team directly. Null if the team was not changed.

from_parent_id: Option<String>

Identifier of the previous parent issue. Can be used to query the issue directly. Null if the parent was not changed or the issue previously had no parent.

to_parent_id: Option<String>

Identifier of the new parent issue. Can be used to query the issue directly. Null if the parent was not changed or the issue was removed from its parent.

from_state_id: Option<String>

Identifier of the previous workflow state (issue status) of the issue. Can be used to query the workflow state directly. Null if the status was not changed.

to_state_id: Option<String>

Identifier of the new workflow state (issue status) of the issue. Can be used to query the workflow state directly. Null if the status was not changed.

from_cycle_id: Option<String>

Identifier of the previous cycle of the issue. Can be used to query the cycle directly. Null if the cycle was not changed or the issue was not in a cycle.

to_cycle_id: Option<String>

Identifier of the new cycle of the issue. Can be used to query the cycle directly. Null if the cycle was not changed or the issue was removed from a cycle.

to_converted_project_id: Option<String>

Identifier of the new project that was created by converting this issue to a project. Can be used to query the project directly. Null if the issue was not converted to a project.

from_project_id: Option<String>

Identifier of the previous project of the issue. Can be used to query the project directly. Null if the project was not changed or the issue was not in a project.

to_project_id: Option<String>

Identifier of the new project of the issue. Can be used to query the project directly. Null if the project was not changed or the issue was removed from a project.

from_estimate: Option<f64>

What the estimate was changed from.

to_estimate: Option<f64>

What the estimate was changed to.

archived: Option<bool>

Whether the issue was archived (true) or unarchived (false) in this change. Null if the archive status was not changed.

trashed: Option<bool>

Whether the issue was trashed or un-trashed.

attachment_id: Option<String>

Identifier of the attachment that was linked to or unlinked from the issue. Can be used to query the attachment directly. Null if no attachment change occurred.

added_label_ids: Option<Vec<String>>

ID’s of labels that were added.

removed_label_ids: Option<Vec<String>>

ID’s of labels that were removed.

added_to_release_ids: Option<Vec<String>>

ALPHA ID’s of releases that the issue was added to.

removed_from_release_ids: Option<Vec<String>>

ALPHA ID’s of releases that the issue was removed from.

relation_changes: Option<Vec<IssueRelationHistoryPayload>>

Changed issue relationships.

auto_closed: Option<bool>

Whether the issue was auto-closed.

auto_archived: Option<bool>

Whether the issue was auto-archived.

from_due_date: Option<NaiveDate>

What the due date was changed from.

to_due_date: Option<NaiveDate>

What the due date was changed to.

customer_need_id: Option<String>

Deprecated Identifier of the customer need that was linked to the issue. Use customer need related arrays in changes instead.

changes: Option<Value>

Internal Serialized JSON representing changes for certain non-relational properties.

actor: Option<User>

The actor that performed the actions. This field may be empty in the case of integrations or automations.

actors: Option<Vec<User>>

The actors that performed the actions. This field may be empty in the case of integrations or automations.

description_updated_by: Option<Vec<User>>

The actors that edited the description of the issue, if any.

from_assignee: Option<User>

The user that was unassigned from the issue.

to_assignee: Option<User>

The user that was assigned to the issue.

from_cycle: Option<Cycle>

The cycle that the issue was moved from.

to_cycle: Option<Cycle>

The cycle that the issue was moved to.

to_converted_project: Option<Project>

The new project created from the issue.

from_delegate: Option<User>

The app user from whom the issue delegation was transferred.

to_delegate: Option<User>

The app user to whom the issue delegation was transferred.

from_project: Option<Project>

The project that the issue was moved from.

to_project: Option<Project>

The project that the issue was moved to.

from_state: Option<WorkflowState>

The state that the issue was moved from.

to_state: Option<WorkflowState>

The state that the issue was moved to.

from_team: Option<Team>

The team that the issue was moved from.

to_team: Option<Team>

The team that the issue was moved to.

from_parent: Option<Issue>

The parent issue that the issue was moved from.

to_parent: Option<Issue>

The parent issue that the issue was moved to.

attachment: Option<Attachment>

The linked attachment.

issue_import: Option<IssueImport>

The import record.

triage_responsibility_notified_users: Option<Vec<User>>

The users that were notified of the issue.

triage_responsibility_auto_assigned: Option<bool>

Boolean indicating if the issue was auto-assigned using the triage responsibility feature.

triage_responsibility_team: Option<Team>

The team that triggered the triage responsibility action.

from_project_milestone: Option<ProjectMilestone>

The project milestone that the issue was moved from.

to_project_milestone: Option<ProjectMilestone>

The project milestone that the issue was moved to.

from_sla_started_at: Option<DateTime<Utc>>

The time at which the issue’s SLA was previously started.

to_sla_started_at: Option<DateTime<Utc>>

The time at which the issue’s SLA is now started.

from_sla_breaches_at: Option<DateTime<Utc>>

The SLA breach time that was previously set on the issue.

to_sla_breaches_at: Option<DateTime<Utc>>

The SLA breach time that is now set on the issue.

from_sla_breached: Option<bool>

Whether the issue had previously breached its SLA.

to_sla_breached: Option<bool>

Whether the issue has now breached its SLA.

from_sla_type: Option<String>

The type of SLA that was previously set on the issue.

to_sla_type: Option<String>

The type of SLA that is now set on the issue.

bot_actor: Option<ActorBot>

The bot that performed the action.

added_labels: Option<Vec<IssueLabel>>

The labels that were added to the issue.

removed_labels: Option<Vec<IssueLabel>>

The labels that were removed from the issue.

added_to_releases: Option<Vec<Release>>

The releases that the issue was added to.

removed_from_releases: Option<Vec<Release>>

The releases that the issue was removed from.

triage_rule_metadata: Option<IssueHistoryTriageRuleMetadata>

INTERNAL Metadata about the triage rule that made changes to the issue.

workflow_metadata: Option<IssueHistoryWorkflowMetadata>

INTERNAL Metadata about the workflow that made changes to the issue.