pub struct IssueLabel {Show 18 fields
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub name: Option<String>,
pub description: Option<String>,
pub color: Option<String>,
pub is_group: Option<bool>,
pub last_applied_at: Option<DateTime<Utc>>,
pub retired_at: Option<DateTime<Utc>>,
pub organization: Option<Box<Organization>>,
pub team: Option<Box<Team>>,
pub creator: Option<Box<User>>,
pub retired_by: Option<Box<User>>,
pub parent: Option<Box<IssueLabel>>,
pub inherited_from: Option<Box<IssueLabel>>,
pub issues: Option<IssueConnection>,
pub children: Option<IssueLabelConnection>,
}Expand description
Labels that can be associated with issues. Labels help categorize and filter issues across a workspace. They can be workspace-level (shared across all teams) or team-scoped. Labels have a color for visual identification and can be organized hierarchically into groups, where a parent label acts as a group containing child labels. Labels may also be inherited from parent teams to sub-teams.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
name: Option<String>The label’s name.
description: Option<String>The label’s description.
color: Option<String>The label’s color as a HEX string (e.g., ‘#EB5757’). Used for visual identification of the label in the UI.
is_group: Option<bool>Whether the label is a group. When true, this label acts as a container for child labels and cannot be directly applied to issues or projects. When false, the label can be directly applied.
last_applied_at: Option<DateTime<Utc>>The date when the label was last applied to an issue or project. Null if the label has never been applied.
retired_at: Option<DateTime<Utc>>Internal When the label was retired.
organization: Option<Box<Organization>>team: Option<Box<Team>>The team that the label is scoped to. If null, the label is a workspace-level label available to all teams in the workspace.
creator: Option<Box<User>>The user who created the label.
retired_by: Option<Box<User>>The user who retired the label.
parent: Option<Box<IssueLabel>>The parent label.
inherited_from: Option<Box<IssueLabel>>The original workspace or parent-team label that this label was inherited from. Null if the label is not inherited.
issues: Option<IssueConnection>Issues associated with the label.
children: Option<IssueLabelConnection>Child labels within this label group. Only populated when the label is a group (isGroup is true).