pub struct IssueSharedAccess {
pub is_shared: Option<bool>,
pub viewer_has_only_shared_access: Option<bool>,
pub shared_with_count: Option<i64>,
pub shared_with_users: Option<Vec<User>>,
pub disallowed_issue_fields: Option<Vec<IssueSharedAccessDisallowedField>>,
}Expand description
Metadata about an issue’s shared access state, including which users the issue is shared with and any field restrictions for shared-only viewers.
Fields
Whether this issue has been shared with users outside the team.
Whether the viewer can access this issue only through issue sharing.
The number of users this issue is shared with.
Users this issue is shared with.
disallowed_issue_fields: Option<Vec<IssueSharedAccessDisallowedField>>Issue update fields the viewer cannot modify due to shared-only access.