pub struct NotificationDeliveryPreferencesDay {
pub start: Option<String>,
pub end: Option<String>,
}Expand description
A user’s notification delivery window for a specific day of the week. Defines the time range during which notifications will be delivered.
Fields
start: Option<String>The start time of the notification delivery window in HH:MM military time format (e.g., ‘09:00’). Must be earlier than ‘end’.
end: Option<String>The end time of the notification delivery window in HH:MM military time format (e.g., ‘18:00’). Must be later than ‘start’.