OrganizationDomain

Struct OrganizationDomain 

pub struct OrganizationDomain {
    pub id: Option<String>,
    pub created_at: Option<DateTime<Utc>>,
    pub updated_at: Option<DateTime<Utc>>,
    pub archived_at: Option<DateTime<Utc>>,
    pub identity_provider: Option<IdentityProvider>,
    pub name: Option<String>,
    pub verified: Option<bool>,
    pub verification_email: Option<String>,
    pub creator: Option<User>,
    pub auth_type: Option<OrganizationDomainAuthType>,
    pub claimed: Option<bool>,
    pub disable_organization_creation: Option<bool>,
}
A verified email domain associated with a workspace. Domains are used for automatic team joining, SSO/SAML authentication, and controlling workspace access. Each domain has an authentication type (general or SAML) and can be verified via email or DNS.

Fields

id: Option<String>

The unique identifier of the entity.

created_at: Option<DateTime<Utc>>

The time at which the entity was created.

updated_at: Option<DateTime<Utc>>

The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.

archived_at: Option<DateTime<Utc>>

The time at which the entity was archived. Null if the entity has not been archived.

identity_provider: Option<IdentityProvider>

The identity provider the domain belongs to.

name: Option<String>

The domain name (e.g., ‘example.com’).

verified: Option<bool>

Whether the domain has been verified via email verification.

verification_email: Option<String>

The email address used to verify this domain. Null if the domain was verified via DNS or has not been verified.

creator: Option<User>

The user who added the domain.

auth_type: Option<OrganizationDomainAuthType>

The authentication type this domain is used for. ‘general’ means standard email-based auth, ‘saml’ means SAML SSO authentication.

claimed: Option<bool>

Whether the domain was claimed by the workspace through DNS TXT record verification. Claimed domains provide stronger ownership proof than email verification and enable additional features like preventing users from creating new workspaces.

disable_organization_creation: Option<bool>

Whether users with email addresses from this domain are prevented from creating new workspaces. Can only be set on claimed domains.