pub struct ProjectRelation {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub type: Option<String>,
pub project: Option<Project>,
pub project_milestone: Option<ProjectMilestone>,
pub anchor_type: Option<String>,
pub related_project: Option<Project>,
pub related_project_milestone: Option<ProjectMilestone>,
pub related_anchor_type: Option<String>,
pub user: Option<User>,
}Expand description
A dependency relation between two projects. Relations can optionally be anchored to specific milestones within each project, allowing fine-grained dependency tracking.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
type: Option<String>The type of dependency relationship from the project to the related project (e.g., blocks).
project: Option<Project>The source project in the dependency relation.
project_milestone: Option<ProjectMilestone>The specific milestone within the source project that the relation is anchored to. Null if the relation applies to the project as a whole.
anchor_type: Option<String>The type of anchor on the source project end of the relation, indicating whether it is anchored to the project itself or a specific milestone.
The target project in the dependency relation.
The specific milestone within the target project that the relation is anchored to. Null if the relation applies to the target project as a whole.
The type of anchor on the target project end of the relation, indicating whether it is anchored to the project itself or a specific milestone.
user: Option<User>The user who last created or modified the relation. Null if the user has been deleted.