pub struct Reaction {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub emoji: Option<String>,
pub issue: Option<Issue>,
pub comment: Option<Comment>,
pub project_update: Option<ProjectUpdate>,
pub initiative_update: Option<InitiativeUpdate>,
pub post: Option<Post>,
pub user: Option<User>,
pub external_user: Option<ExternalUser>,
}Expand description
An emoji reaction on a comment, issue, project update, initiative update, post, pull request, or pull request comment. Each reaction is associated with exactly one parent entity and is created by either a workspace user or an external user. Reactions are persisted individually but surfaced on their parent entities as aggregated reactionData.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
emoji: Option<String>The name of the emoji used for this reaction. For custom workspace emojis, this is the custom emoji name; for standard emojis, this is the normalized emoji name.
issue: Option<Issue>The issue that the reaction is associated with. Null if the reaction belongs to a different parent entity type.
comment: Option<Comment>The comment that the reaction is associated with. Null if the reaction belongs to a different parent entity type.
project_update: Option<ProjectUpdate>The project update that the reaction is associated with. Null if the reaction belongs to a different parent entity type.
initiative_update: Option<InitiativeUpdate>The initiative update that the reaction is associated with. Null if the reaction belongs to a different parent entity type.
post: Option<Post>The post that the reaction is associated with. Null if the reaction belongs to a different parent entity type.
user: Option<User>The workspace user that created the reaction. Null if the reaction was created by an external user through an integration.
external_user: Option<ExternalUser>The external user that created the reaction through an integration. Null if the reaction was created by a workspace user.