pub struct Roadmap {Show 14 fields
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub name: Option<String>,
pub description: Option<String>,
pub organization: Option<Organization>,
pub creator: Option<User>,
pub owner: Option<User>,
pub slug_id: Option<String>,
pub sort_order: Option<f64>,
pub color: Option<String>,
pub projects: Option<ProjectConnection>,
pub url: Option<String>,
}Expand description
Deprecated A roadmap for grouping projects. Use Initiative instead, which supersedes this entity and provides richer hierarchy and tracking capabilities.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
name: Option<String>The name of the roadmap.
description: Option<String>The description of the roadmap.
organization: Option<Organization>The workspace of the roadmap.
creator: Option<User>The user who created the roadmap.
owner: Option<User>The user who owns the roadmap.
slug_id: Option<String>The roadmap’s unique URL slug.
sort_order: Option<f64>The sort order of the roadmap within the workspace.
color: Option<String>The roadmap’s color.
projects: Option<ProjectConnection>Projects associated with the roadmap.
url: Option<String>The canonical url for the roadmap.