pub struct SemanticSearchResult {
pub id: Option<String>,
pub type: Option<SemanticSearchResultType>,
pub issue: Option<Issue>,
pub project: Option<Project>,
pub initiative: Option<Initiative>,
pub document: Option<Document>,
}Expand description
A reference to an entity returned by semantic search, containing its type and ID. Resolve the specific entity using the type-specific field resolvers (issue, project, initiative, document).
Fields
id: Option<String>The unique identifier of the entity.
type: Option<SemanticSearchResultType>The type of the semantic search result.
issue: Option<Issue>The issue entity, if this search result is of type Issue. Null for other result types.
project: Option<Project>The project entity, if this search result is of type Project. Null for other result types.
initiative: Option<Initiative>The initiative entity, if this search result is of type Initiative. Null for other result types.
document: Option<Document>The document entity, if this search result is of type Document. Null for other result types.