pub struct TimeSchedule {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub name: Option<String>,
pub entries: Option<Vec<TimeScheduleEntry>>,
pub external_id: Option<String>,
pub external_url: Option<String>,
pub organization: Option<Box<Organization>>,
pub integration: Option<Box<Integration>>,
}Expand description
A time-based schedule defining on-call rotations or availability windows. Schedules contain a series of time entries, each specifying a user and their active period. They can be synced from external services (such as PagerDuty or Opsgenie) via integrations, or created manually. Schedules are used by triage responsibilities to determine who should be assigned or notified when issues enter triage.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
name: Option<String>The name of the schedule.
entries: Option<Vec<TimeScheduleEntry>>The schedule entries.
external_id: Option<String>The identifier of the external schedule.
external_url: Option<String>The URL to the external schedule.
organization: Option<Box<Organization>>The workspace of the schedule.
integration: Option<Box<Integration>>The identifier of the Linear integration populating the schedule.