TriageResponsibility

Struct TriageResponsibility 

pub struct TriageResponsibility {
    pub id: Option<String>,
    pub created_at: Option<DateTime<Utc>>,
    pub updated_at: Option<DateTime<Utc>>,
    pub archived_at: Option<DateTime<Utc>>,
    pub action: Option<TriageResponsibilityAction>,
    pub manual_selection: Option<TriageResponsibilityManualSelection>,
    pub team: Option<Box<Team>>,
    pub time_schedule: Option<Box<TimeSchedule>>,
    pub current_user: Option<Box<User>>,
}
A team’s triage responsibility configuration that defines how issues entering triage are handled. Each team can have one triage responsibility, which specifies the action to take (notify or assign) and the responsible users, determined either by a manual selection of specific users or by an on-call time schedule.

Fields

id: Option<String>

The unique identifier of the entity.

created_at: Option<DateTime<Utc>>

The time at which the entity was created.

updated_at: Option<DateTime<Utc>>

The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.

archived_at: Option<DateTime<Utc>>

The time at which the entity was archived. Null if the entity has not been archived.

action: Option<TriageResponsibilityAction>

The action to take when an issue is added to triage.

manual_selection: Option<TriageResponsibilityManualSelection>

Set of users used for triage responsibility.

team: Option<Box<Team>>

The team to which the triage responsibility belongs to.

time_schedule: Option<Box<TimeSchedule>>

The time schedule used for scheduling.

current_user: Option<Box<User>>

The user currently responsible for triage.