pub struct WelcomeMessage {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub title: Option<String>,
pub enabled: Option<bool>,
pub updated_by: Option<Box<User>>,
}Expand description
A welcome message configuration for the workspace. When enabled, new users joining the workspace receive a notification with this message in their inbox. Each workspace has at most one welcome message. The message body is stored in a related DocumentContent entity.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
title: Option<String>The title of the welcome message notification. Null defaults to ‘Welcome to {workspace name}’.
enabled: Option<bool>Whether the welcome message is enabled and should be sent to new users joining the workspace.
updated_by: Option<Box<User>>The user who last updated the welcome message configuration. Null if the user’s account has been deleted.