API token resolution.
Supports three sources (in precedence order): explicit token, the
LINEAR_API_TOKEN environment variable, and a token file at any path.
Functions
- token_
from_ env - Resolve a Linear API token from the environment variable
LINEAR_API_TOKEN. - token_
from_ file - Resolve a Linear API token from a file at the given path.