GraphQL input types.
Generated by lineark-codegen — do not edit.
Structs
- Activity
Collection Filter - Activity collection filtering options.
- Activity
Filter - Activity filtering options.
- Agent
Activity Create Input - Input for creating an agent activity.
- Agent
Activity Create Prompt Input InternalInput for creating prompt-type agent activities (created by users).- Agent
Activity Filter - Agent activity filtering options.
- Agent
Activity Prompt Create Input Content InternalInput for creating prompt-type agent activities (created by users).- Agent
Session Create Input InternalInput for creating an agent session on behalf of the current user.- Agent
Session Create OnComment - Input for creating an agent session on a root comment.
- Agent
Session Create OnIssue - Input for creating an agent session on an issue.
- Agent
Session External UrlInput - Input for an external URL associated with an agent session.
- Agent
Session Update External UrlInput - Input for updating the external URLs of an agent session.
- Agent
Session Update Input - Input for updating an agent session.
- Agent
Session User State Input - AiPrompt
Progress Filter InternalAI prompt progress filtering options.- AiPrompt
Progress Status Comparator InternalComparator for the AI prompt workflow status.- AiPrompt
Progress Subscription Filter InternalFilter for AI prompt progress subscription events.- AiPrompt
Type Comparator InternalComparator for the AI prompt workflow type.- Airbyte
Configuration Input - Approximate
Need Count Sort - Customer approximate need count sorting options.
- Assignee
Sort - Issue assignee sorting options.
- Attachment
Collection Filter - Attachment collection filtering options.
- Attachment
Create Input - Input for creating a new issue attachment.
- Attachment
Filter - Attachment filtering options.
- Attachment
Update Input - Input for updating an existing issue attachment.
- Audit
Entry Filter - Audit entry filtering options.
- Boolean
Comparator - Comparator for booleans.
- Candidate
Repository - A candidate code repository to consider when generating repository suggestions for an issue.
- Comment
Collection Filter - Comment filtering options.
- Comment
Create Input - Input for creating a new comment.
- Comment
Filter - Comment filtering options.
- Comment
Update Input - Input for updating an existing comment.
- Completed
AtSort - Issue completion date sorting options.
- Contact
Create Input - Input for submitting a support contact message from an authenticated user.
- Contact
Sales Create Input INTERNALInput for submitting a sales or pricing inquiry to the Linear sales team. Small companies are routed to Intercom support, while larger companies are routed to HubSpot.- Content
Comparator InternalComparator for content.- Create
Organization Input - Created
AtSort - Issue creation date sorting options.
- Custom
View Create Input - Input for creating a new custom view. A name is required. Optionally scope the view to a team, project, or initiative.
- Custom
View Created AtSort - Custom view creation date sorting options.
- Custom
View Filter - Custom view filtering options.
- Custom
View Name Sort - Custom view name sorting options.
- Custom
View Shared Sort - Custom view shared status sorting options. Ascending order puts shared views last.
- Custom
View Sort Input - Custom
View Update Input - Input for updating an existing custom view. All fields are optional; only provided fields will be updated.
- Custom
View Updated AtSort - Custom view update date sorting options.
- Customer
Count Sort - Issue customer count sorting options.
- Customer
Create Input - Input for creating a new customer in the workspace.
- Customer
Created AtSort - Customer creation date sorting options.
- Customer
Filter - Customer filtering options.
- Customer
Important Count Sort - Issue customer important count sorting options.
- Customer
Need Collection Filter - Customer needs filtering options.
- Customer
Need Create From Attachment Input - Input for creating a customer need from an existing issue attachment. If the attachment already has an archived need, it will be unarchived instead.
- Customer
Need Create Input - Input for creating a customer need linked to an issue or project. Either issueId or projectId must be provided.
- Customer
Need Filter - Customer filtering options.
- Customer
Need Update Input - Input for updating a customer need. Supports reassigning the customer, moving to a different issue or project, changing priority, and updating body content.
- Customer
Revenue Sort - Issue customer revenue sorting options.
- Customer
Sort - Issue customer sorting options.
- Customer
Sort Input - Customer sorting options.
- Customer
Status Create Input - Input for creating a customer status in the workspace’s customer lifecycle flow.
- Customer
Status Filter - Customer status filtering options.
- Customer
Status Sort - Customer status sorting options.
- Customer
Status Update Input - Input for updating an existing customer status.
- Customer
Tier Create Input - Input for creating a customer tier in the workspace’s customer tier ordering.
- Customer
Tier Filter - Customer tier filtering options.
- Customer
Tier Update Input - Input for updating an existing customer tier.
- Customer
Update Input - Input for updating an existing customer.
- Customer
Upsert Input - Input for upserting a customer. Matches against existing customers using id, externalId, slackChannelId, or domains. Creates a new customer if no match is found.
- Cycle
Create Input - Input for creating a new cycle.
- Cycle
Filter - Cycle filtering options.
- Cycle
Period Comparator - Comparator for period when issue was added to a cycle.
- Cycle
Shift AllInput - Input for shifting all cycles from a certain cycle onwards by a certain number of days.
- Cycle
Sort - Issue cycle sorting options.
- Cycle
Update Input - Input for updating an existing cycle.
- Date
Comparator - Comparator for dates.
- Delegate
Sort - Issue delegate sorting options.
- Delete
Organization Input - Input for confirming workspace deletion with a verification code.
- Document
Create Input - Input for creating a new document.
- Document
Filter - Document filtering options.
- Document
Update Input - Input for updating an existing document.
- DueDate
Sort - Issue due date sorting options.
- Email
Intake Address Create Input - Input for creating a new email intake address.
- Email
Intake Address Update Input - Input for updating an existing email intake address.
- Email
Unsubscribe Input - Input for unsubscribing a user from a specific email notification type.
- Email
User Account Auth Challenge Input - Emoji
Create Input - Input for creating a new custom emoji.
- Entity
External Link Create Input - Input for creating a new external link on an entity. A URL, label, and exactly one parent entity (initiative, project, team, release, or cycle) are required.
- Entity
External Link Update Input - Input for updating an existing external link. All fields are optional; only provided fields will be updated.
- Estimate
Comparator - Comparator for estimates.
- Estimate
Sort - Issue estimate sorting options.
- Event
Tracking Input - Input for tracking an anonymous analytics event.
- Favorite
Create Input - Input for creating a favorite. Exactly one target entity must be specified (e.g., issueId, projectId, customViewId, folderName, etc.).
- Favorite
Update Input - Input for updating a favorite’s position, parent folder, or folder name.
- Feed
Item Filter - Feed item filtering options
- Front
Settings Input - GitAutomation
State Create Input - Input for creating a new Git automation rule.
- GitAutomation
State Update Input - Input for updating an existing Git automation rule.
- GitAutomation
Target Branch Create Input - Input for creating a new Git target branch definition.
- GitAutomation
Target Branch Update Input - Input for updating an existing Git target branch definition.
- GitHub
Import Settings Input - GitHub
Personal Settings Input - GitHub
Repo Input - GitHub
Repo Mapping Input - GitHub
Settings Input - GitLab
Settings Input - Gong
Recording Import Config Input - Gong
Settings Input - Google
Sheets Export Settings - Google
Sheets Settings Input - Google
User Account Auth Input - IDComparator
- Comparator for identifiers.
- Inheritance
Entity Mapping - Initiative
Collection Filter - Initiative collection filtering options.
- Initiative
Create Input - The properties of the initiative to create.
- Initiative
Created AtSort - Initiative creation date sorting options.
- Initiative
Filter - Initiative filtering options.
- Initiative
Health Sort - Initiative health sorting options.
- Initiative
Health Updated AtSort - Initiative health update date sorting options.
- Initiative
Manual Sort - Initiative manual sorting options.
- Initiative
Name Sort - Initiative name sorting options.
- Initiative
Owner Sort - Initiative owner sorting options.
- Initiative
Relation Create Input - Input for creating a parent-child relationship between two initiatives. The initiativeId is the parent and the relatedInitiativeId is the child.
- Initiative
Relation Update Input - The properties of the initiative relation to update.
- Initiative
Sort Input - Initiative sorting options.
- Initiative
Target Date Sort - Initiative target date sorting options.
- Initiative
ToProject Create Input - The properties of the initiativeToProject to create.
- Initiative
ToProject Update Input - The properties of the initiative-to-project association to update.
- Initiative
Update Create Input - Input for creating a new initiative update.
- Initiative
Update Filter - Options for filtering initiative updates.
- Initiative
Update Input - The properties of the initiative to update.
- Initiative
Update Update Input - Input for updating an existing initiative update.
- Initiative
Updated AtSort - Initiative update date sorting options.
- Initiative
Updates Collection Filter - Collection filtering options for filtering initiatives by initiative updates.
- Initiative
Updates Filter - Options for filtering initiatives by initiative updates.
- Integration
Customer Data Attributes Refresh Input - Integration
Request Input - Input for requesting a currently unavailable integration.
- Integration
Settings Input - Integration
Template Create Input - Input for creating a new integration template.
- Integration
Update Input - Integrations
Settings Create Input - Integrations
Settings Update Input - Intercom
Settings Input - Issue
Batch Create Input - Input for creating multiple issues at once in a batch operation. Up to 50 issues can be created in a single batch.
- Issue
Collection Filter - Issue filtering options.
- Issue
Create Input - Input for creating a new issue. At minimum, a team must be specified. A title is required unless a template is provided. All other fields are optional and will use defaults from the team or template if not specified.
- Issue
Filter - Issue filtering options.
- IssueID
Comparator - Comparator for issue identifiers.
- Issue
Import Update Input - Input for updating an import job’s mapping configuration, such as user and workflow state mappings between the source service and Linear.
- Issue
Label Collection Filter - Issue label filtering options.
- Issue
Label Create Input - Input for creating a new label. A name is required. If no team is specified, the label is created as a workspace-level label available to all teams.
- Issue
Label Filter - Issue label filtering options.
- Issue
Label Update Input - Input for updating an existing label. All fields are optional; only provided fields will be updated.
- Issue
Reference Input - A reference to an issue discovered during release sync, linking the issue identifier to the commit SHA where the reference was found.
- Issue
Relation Create Input - Input for creating a new issue relation between two issues. Both the source issue and related issue must be specified along with the relationship type.
- Issue
Relation Update Input - Input for updating an existing issue relation. All fields are optional; only provided fields will be updated.
- Issue
Sort Input - Issue sorting options.
- Issue
Subscription Filter - Filter for issue subscription events.
- Issue
Suggestion Collection Filter - IssueSuggestion collection filtering options.
- Issue
Suggestion Filter - IssueSuggestion filtering options.
- Issue
ToRelease Create Input ALPHAInput for creating a new association between an issue and a release. Both an issue identifier and a release identifier must be provided.- Issue
Update Input - Input for updating an existing issue. All fields are optional; only provided fields will be updated. Setting a field to null (where supported) will clear the value.
- Jira
Configuration Input - Jira
Fetch Project Statuses Input - Jira
Linear Mapping Input - Jira
Personal Settings Input - Jira
Project Data Input - Jira
Settings Input - Jira
Update Input - Join
Organization Input - Label
Group Sort - Issue label-group sorting options.
- Label
Sort - Issue label sorting options.
- Launch
Darkly Settings Input - Link
Count Sort ALPHAIssue link count sorting options.- Manual
Sort - Issue manual sorting options.
- McpServer
Custom Header Input - An additional HTTP header sent with requests to the connected MCP server. Header values are stored securely.
- Microsoft
Teams Post Settings Input - Microsoft
Teams Settings Input - Milestone
Sort - Issue project milestone options.
- Name
Sort - Customer name sorting options.
- Notification
Category Preferences Input - Notification
Delivery Preferences Channel Input - Notification
Delivery Preferences DayInput - Notification
Delivery Preferences Input - Notification
Delivery Preferences Schedule Input - Notification
Entity Input - Identifies a specific entity whose related notifications should be targeted by a batch operation. Exactly one entity identifier should be provided.
- Notification
Filter - Notification filtering options.
- Notification
Subscription Create Input - Input for creating a notification subscription. Exactly one target entity (customer, custom view, cycle, initiative, label, project, team, or user) must be specified along with the notification types to subscribe to.
- Notification
Subscription Update Input - Input for updating an existing notification subscription. Allows changing the subscribed notification types and active state.
- Notification
Update Input - Input for updating a notification’s read and snooze state.
- Notion
Settings Input - Nullable
Comment Filter - Comment filtering options.
- Nullable
Customer Filter - Customer filtering options.
- Nullable
Cycle Filter - Cycle filtering options.
- Nullable
Date Comparator - Comparator for optional dates.
- Nullable
Document Content Filter - Document content filtering options.
- Nullable
Duration Comparator - Nullable comparator for optional durations.
- Nullable
Initiative Filter - Initiative filtering options.
- Nullable
Issue Filter - Issue filtering options.
- Nullable
Number Comparator - Comparator for optional numbers.
- Nullable
Project Filter - Project filtering options.
- Nullable
Project Milestone Filter - Project milestone filtering options.
- Nullable
Project Update Filter - Nullable project update filtering options.
- Nullable
String Comparator - Comparator for optional strings.
- Nullable
Team Filter - Team filtering options.
- Nullable
Template Filter - Template filtering options.
- Nullable
Timeless Date Comparator - Comparator for optional timeless dates.
- Nullable
User Filter - User filtering options.
- Number
Comparator - Comparator for numbers.
- Onboarding
Customer Survey - Opsgenie
Input - Organization
Auth Settings Input - Input for updating workspace authentication settings.
- Organization
Domain Create Input - Organization
Domain Update Input - Organization
Domain Verification Input - Organization
Invite Create Input - Organization
Invite Update Input - Organization
IpRestriction Input INTERNALOrganization IP restriction configuration.- Organization
Linear Agent McpServer Allowlist Entry Input InternalAn MCP server URL entry for the Linear Agent allowlist.- Organization
Linear Agent Settings Input InternalInput for updating Linear Agent settings for the workspace.- Organization
Security Settings Input - Input for updating workspace security settings such as role-based access controls.
- Organization
Start Trial Input - Input for starting a workspace trial on a specific plan.
- Organization
Update Input - Input for updating the workspace.
- Owner
Sort - Customer owner sorting options.
- Pager
Duty Input - Partial
Notification Channel Preferences Input - Priority
Sort - Issue priority sorting options.
- Project
Collection Filter - Project filtering options.
- Project
Create Input - Input for creating a new project. A name and at least one team are required. All other fields are optional and will use defaults if not specified.
- Project
Created AtSort - Project creation date sorting options.
- Project
Filter - Project filtering options.
- Project
Health Sort - Project health sorting options.
- Project
Label Collection Filter - Project label filtering options.
- Project
Label Create Input - Input for creating a new project label. A name is required. The label is created as a workspace-level label available to all projects.
- Project
Label Filter - Project label filtering options.
- Project
Label Update Input - Input for updating an existing project label. All fields are optional; only provided fields will be updated.
- Project
Lead Sort - Project lead sorting options.
- Project
Manual Sort - Project manual order sorting options.
- Project
Milestone Collection Filter - Milestone collection filtering options.
- Project
Milestone Create Input - Input for creating a new project milestone.
- Project
Milestone Filter - Project milestone filtering options.
- Project
Milestone Move Input InternalInput for moving a project milestone to another project.- Project
Milestone Move Issue ToTeam Input InternalUsed for ProjectMilestoneMoveInput to describe a mapping between an issue and its team.- Project
Milestone Move Project Teams Input InternalUsed for ProjectMilestoneMoveInput to describe a snapshot of a project and its team ids- Project
Milestone Update Input - Input for updating an existing project milestone.
- Project
Name Sort - Project name sorting options.
- Project
Priority Sort - Project priority sorting options.
- Project
Relation Create Input - Input for creating a new project relation.
- Project
Relation Update Input - Input for updating an existing project relation.
- Project
Sort - Issue project sorting options.
- Project
Sort Input - Project sorting options.
- Project
Status Create Input - Input for creating a new project status.
- Project
Status Filter - Project status filtering options.
- Project
Status Sort - Project status sorting options.
- Project
Status Update Input - Input for updating an existing project status.
- Project
Update Create Input - Input for creating a new project update.
- Project
Update Filter - Options for filtering project updates.
- Project
Update Input - Input for updating an existing project. All fields are optional; only provided fields will be updated. Setting a field to null (where supported) will clear the value.
- Project
Update Update Input - Input for updating an existing project update.
- Project
Updated AtSort - Project update date sorting options.
- Project
Updates Collection Filter - Collection filtering options for filtering projects by project updates.
- Project
Updates Filter - Options for filtering projects by project updates.
- Pull
Request Reference Input - A reference to a pull request by its repository owner, name, and pull request number. Used during release sync to look up pull requests and associate their linked issues with the release.
- Push
Subscription Create Input - Input for creating a push subscription to receive push notifications on a device or browser.
- Reaction
Collection Filter - Reaction filtering options.
- Reaction
Create Input - Input for creating a new reaction.
- Reaction
Filter - Reaction filtering options.
- Relation
Exists Comparator - Comparator for relation existence.
- Release
Collection Filter ALPHARelease collection filtering options.- Release
Complete Input - Input for completing a release in a specific pipeline.
- Release
Complete Input Base - Base input for completing a release. Contains the optional version and commit SHA. The pipeline ID is provided separately or inferred from the access key.
- Release
Create Input - The input for creating a release.
- Release
Debug Sink Input - Diagnostic data captured during release sync, including inspected commits, discovered issue references, and pull request metadata. Stored on the release for debugging release association issues.
- Release
Filter ALPHARelease filtering options.- Release
Note Create Input ALPHAInput for creating a release note.- Release
Note Update Input ALPHAInput for updating a release note.- Release
Pipeline Collection Filter ALPHARelease pipeline collection filtering options.- Release
Pipeline Create Input - Input for creating a new release pipeline.
- Release
Pipeline Filter ALPHARelease pipeline filtering options.- Release
Pipeline Name Sort - Release pipeline name sorting options.
- Release
Pipeline Sort Input - Release pipeline sorting options.
- Release
Pipeline Update Input - Input for updating an existing release pipeline.
- Release
Sort InternalIssue release sorting options.- Release
Sort Input - Release sorting options.
- Release
Stage Create Input - Input for creating a new release stage.
- Release
Stage Filter ALPHARelease stage filtering options.- Release
Stage Sort - Release stage sorting options.
- Release
Stage Type Comparator ALPHAComparator for release stage type.- Release
Stage Update Input - Input for updating an existing release stage.
- Release
Sync Input - Input for syncing release data to a specific pipeline. Extends the base sync input with the target pipeline identifier.
- Release
Sync Input Base - Base input for syncing release data, containing the commit SHA, issue references, pull request references, and optional metadata. Does not include the pipeline ID, which is provided separately or inferred from the access key.
- Release
Update ByPipeline Input - Input for updating a release by pipeline identifier. Extends the base update input with the target pipeline identifier.
- Release
Update ByPipeline Input Base - Base input for updating a release by pipeline. Contains optional version and stage name. The pipeline ID is provided separately or inferred from the access key.
- Release
Update Input - Input for updating an existing release.
- Repository
Data Input - Metadata about the source code repository from which a release is being synced, including the hosting provider and repository coordinates.
- Revenue
Sort - Customer revenue sorting options.
- Roadmap
Collection Filter - Roadmap collection filtering options.
- Roadmap
Create Input - Input for creating a new roadmap.
- Roadmap
Filter - Roadmap filtering options.
- Roadmap
ToProject Create Input - Input for creating a new roadmap-to-project mapping.
- Roadmap
ToProject Update Input - Input for updating an existing roadmap-to-project mapping.
- Roadmap
Update Input - Input for updating an existing roadmap.
- Root
Issue Sort - Issue root-issue sorting options.
- Salesforce
Metadata Integration Comparator INTERNALComparator for Salesforce metadata.- Salesforce
Settings Input - Semantic
Search Filters - Filters for semantic search results.
- Sentry
Settings Input - Size
Sort - Customer size sorting options.
- SlaStatus
Comparator - Comparator for sla status.
- SlaStatus
Sort - Issue SLA status sorting options.
- Slack
Asks Settings Input - Slack
Asks Team Settings Input - Slack
Channel Name Mapping Input - Slack
Post Settings Input - Slack
Settings Input - Source
Metadata Comparator - Comparator for issue source type.
- Source
Type Comparator - Comparator for
sourceTypefield. - Start
Date Sort - Project start date sorting options.
- String
Array Comparator - Comparator for strings.
- String
Comparator - Comparator for strings.
- String
Item Comparator - Comparator for strings in arrays.
- SubType
Comparator - Comparator for source type.
- Target
Date Sort - Project target date sorting options.
- Team
Collection Filter - Team collection filtering options.
- Team
Create Input - Team
Filter - Team filtering options.
- Team
Membership Create Input - Input for creating a new team membership.
- Team
Membership Update Input - Input for updating an existing team membership.
- Team
Security Settings Input - Team
Sort - Issue team sorting options.
- Team
Update Input - Template
Create Input - Input for creating a new template. A name, type, and template data are required. If no team is specified, the template is shared across the workspace.
- Template
Update Input - Input for updating an existing template. All fields are optional; only provided fields will be updated.
- Tier
Sort - Customer tier sorting options.
- Time
InStatus Sort - Issue time in status sorting options.
- Time
Schedule Create Input - Input for creating a new time schedule.
- Time
Schedule Entry Input - Time
Schedule Update Input - Input for updating an existing time schedule.
- Title
Sort - Issue title sorting options.
- Token
User Account Auth Input - Triage
Responsibility Create Input - Input for creating a new triage responsibility.
- Triage
Responsibility Manual Selection Input - Manual triage responsibility using a set of users.
- Triage
Responsibility Update Input - Input for updating an existing triage responsibility.
- Updated
AtSort - Issue update date sorting options.
- User
Collection Filter - User filtering options.
- User
Display Name Sort - User display name sorting options.
- User
Filter - User filtering options.
- User
Name Sort - User name sorting options.
- User
Settings Update Input - User
Sort Input - User sorting options.
- User
Update Input - Input for updating the authenticated user.
- View
Preferences Create Input - Input for creating view preferences.
- View
Preferences Update Input - Input for updating view preferences.
- Webhook
Create Input - Input for creating a new webhook.
- Webhook
Update Input - Input for updating an existing webhook.
- Workflow
State Create Input - Input for creating a new workflow state (issue status) in a team. The name, type, color, and team are required.
- Workflow
State Filter - Workflow state filtering options.
- Workflow
State Sort - Issue workflow state sorting options.
- Workflow
State Update Input - Input for updating an existing workflow state. All fields are optional; only provided fields will be updated. The state type cannot be changed after creation.
- Zendesk
Settings Input