pub struct CommentCreateInput {Show 18 fields
pub id: MaybeUndefined<String>,
pub body: MaybeUndefined<String>,
pub body_data: MaybeUndefined<Value>,
pub issue_id: MaybeUndefined<String>,
pub project_update_id: MaybeUndefined<String>,
pub initiative_update_id: MaybeUndefined<String>,
pub post_id: MaybeUndefined<String>,
pub document_content_id: MaybeUndefined<String>,
pub project_id: MaybeUndefined<String>,
pub initiative_id: MaybeUndefined<String>,
pub parent_id: MaybeUndefined<String>,
pub create_as_user: MaybeUndefined<String>,
pub display_icon_url: MaybeUndefined<String>,
pub created_at: MaybeUndefined<DateTime<Utc>>,
pub do_not_subscribe_to_issue: MaybeUndefined<bool>,
pub create_on_synced_slack_thread: MaybeUndefined<bool>,
pub quoted_text: MaybeUndefined<String>,
pub subscriber_ids: MaybeUndefined<Vec<String>>,
}Expand description
Input for creating a new comment.
Fields
id: MaybeUndefined<String>The identifier in UUID v4 format. If none is provided, the backend will generate one.
body: MaybeUndefined<String>The comment content in markdown format.
body_data: MaybeUndefined<Value>Internal The comment content as a Prosemirror document.
issue_id: MaybeUndefined<String>The issue to associate the comment with. Can be a UUID or issue identifier (e.g., ‘LIN-123’).
project_update_id: MaybeUndefined<String>The project update to associate the comment with.
initiative_update_id: MaybeUndefined<String>The initiative update to associate the comment with.
post_id: MaybeUndefined<String>The post to associate the comment with.
document_content_id: MaybeUndefined<String>The document content to associate the comment with.
project_id: MaybeUndefined<String>Internal The project to associate the comment with.
initiative_id: MaybeUndefined<String>Internal The initiative to associate the comment with.
parent_id: MaybeUndefined<String>The parent comment under which to nest a current comment.
create_as_user: MaybeUndefined<String>Create comment as a user with the provided name. This option is only available to OAuth applications creating comments in actor=app mode.
display_icon_url: MaybeUndefined<String>Provide an external user avatar URL. Can only be used in conjunction with the createAsUser options. This option is only available to OAuth applications creating comments in actor=app mode.
created_at: MaybeUndefined<DateTime<Utc>>The time at which the comment was created (e.g. if importing from another system). Must be a time in the past. If none is provided, the backend will generate the time as now.
do_not_subscribe_to_issue: MaybeUndefined<bool>Flag to prevent auto subscription to the issue the comment is created on.
create_on_synced_slack_thread: MaybeUndefined<bool>Flag to indicate this comment should be created on the issue’s synced Slack comment thread. If no synced Slack comment thread exists, the mutation will fail. If there are multiple synced Slack threads on the issue, the oldest one will be targeted.
quoted_text: MaybeUndefined<String>The text that this comment references. Only defined for inline comments.
subscriber_ids: MaybeUndefined<Vec<String>>INTERNAL The identifiers of the users subscribing to this comment thread.