team_create

Function team_create 

pub async fn team_create<T: DeserializeOwned + GraphQLFields<FullType = Team>>(
    client: &Client,
    copy_settings_from_team_id: Option<String>,
    input: TeamCreateInput,
) -> Result<T, LinearError>
Creates a new team. The user who creates the team will automatically be added as a member to the newly created team.

Full type: Team