pub struct AgentActivity {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub agent_session: Option<AgentSession>,
pub source_comment: Option<Comment>,
pub user: Option<User>,
pub source_metadata: Option<Value>,
pub signal: Option<AgentActivitySignal>,
pub ephemeral: Option<bool>,
pub contextual_metadata: Option<Value>,
pub signal_metadata: Option<Value>,
}Expand description
An activity performed by or directed at an AI coding agent during a session. Activities represent the observable steps of an agent’s work, including thoughts, actions (tool calls), responses, prompts from users, errors, and elicitation requests. Each activity belongs to an agent session and is associated with the user who initiated it.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
agent_session: Option<AgentSession>The agent session this activity belongs to.
source_comment: Option<Comment>The source comment this activity is linked to. Null if the activity was not triggered by a comment.
user: Option<User>The user who created this agent activity.
source_metadata: Option<Value>Metadata about the external source that created this agent activity.
signal: Option<AgentActivitySignal>An optional modifier that provides additional instructions on how the activity should be interpreted.
ephemeral: Option<bool>Whether the activity is ephemeral, and should disappear after the next agent activity.
contextual_metadata: Option<Value>Internal Metadata about user-provided contextual information for this agent activity.
signal_metadata: Option<Value>Metadata about this agent activity’s signal.