pub struct ExternalUser {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub name: Option<String>,
pub display_name: Option<String>,
pub email: Option<String>,
pub avatar_url: Option<String>,
pub organization: Option<Box<Organization>>,
pub last_seen: Option<DateTime<Utc>>,
}Expand description
An external user who interacts with Linear through an integrated external service (such as Slack, Jira, GitHub, GitLab, Salesforce, or Microsoft Teams) but does not have a Linear account. External users can create issues, post comments, and add reactions from their respective platforms. They are identified by service-specific user IDs and may optionally have an email address. External users are scoped to a single workspace.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
name: Option<String>The external user’s full name.
display_name: Option<String>The external user’s display name. Unique within each workspace. Can match the display name of an actual user.
email: Option<String>The external user’s email address.
avatar_url: Option<String>A URL to the external user’s avatar image. Null if no avatar is available from the external service.
organization: Option<Box<Organization>>The workspace that the external user belongs to.
last_seen: Option<DateTime<Utc>>The last time the external user was seen interacting with Linear through their external service. Defaults to the creation time and is updated on subsequent interactions.