pub struct GitAutomationState {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub state: Option<WorkflowState>,
pub team: Option<Team>,
pub target_branch: Option<GitAutomationTargetBranch>,
pub event: Option<GitAutomationStates>,
pub branch_pattern: Option<String>,
}Expand description
A Git automation rule that automatically transitions issues to a specified workflow state when a Git event occurs (e.g., when a PR is opened, move the linked issue to ‘In Review’). Each rule is scoped to a team and optionally to a specific target branch. When no target branch is specified, the rule acts as the default for all branches. Target-branch-specific rules override the defaults.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
state: Option<WorkflowState>The workflow state that linked issues will be transitioned to when the Git event fires. Null if this rule is configured to take no action, overriding any default rule for the same event.
team: Option<Team>The team that this automation rule belongs to. Issues must belong to this team for the automation to apply.
target_branch: Option<GitAutomationTargetBranch>The target branch that this automation rule applies to. When set, this rule only fires for pull requests targeting the specified branch pattern, overriding any default rule for the same event. Null if this is a default rule that applies to all branches.
event: Option<GitAutomationStates>The Git event that triggers this automation rule (e.g., branch created, PR opened for review, or PR merged).
branch_pattern: Option<String>DEPRECATED The target branch, if null, the automation will be triggered on any branch.