pub struct IssueDraft {Show 30 fields
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub title: Option<String>,
pub description: Option<String>,
pub priority: Option<f64>,
pub estimate: Option<f64>,
pub due_date: Option<NaiveDate>,
pub label_ids: Option<Vec<String>>,
pub team_id: Option<String>,
pub cycle_id: Option<String>,
pub project_id: Option<String>,
pub project_milestone_id: Option<String>,
pub creator: Option<User>,
pub assignee_id: Option<String>,
pub delegate_id: Option<String>,
pub state_id: Option<String>,
pub parent: Option<Box<IssueDraft>>,
pub parent_id: Option<String>,
pub source_comment_id: Option<String>,
pub parent_issue: Option<Issue>,
pub parent_issue_id: Option<String>,
pub sub_issue_sort_order: Option<f64>,
pub priority_label: Option<String>,
pub description_data: Option<Value>,
pub attachments: Option<Value>,
pub needs: Option<Value>,
pub release_ids: Option<Vec<String>>,
pub schedule: Option<Value>,
}Expand description
Internal A draft issue that has not yet been created as a full issue. Drafts allow users to prepare issue details (title, description, labels, assignee, etc.) before committing them. Drafts belong to a team and a creator, and support a parent-child hierarchy similar to issues. A draft can have either a parent draft or a parent issue, but not both.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
title: Option<String>The draft’s title. This will become the issue’s title when the draft is published.
description: Option<String>The draft’s description in markdown format.
priority: Option<f64>The priority of the draft. 0 = No priority, 1 = Urgent, 2 = High, 3 = Normal, 4 = Low.
estimate: Option<f64>The estimate of the complexity of the draft. Null if no estimate has been set.
due_date: Option<NaiveDate>The date at which the issue would be due.
label_ids: Option<Vec<String>>Identifiers of the labels added to the draft. These labels will be applied to the issue when the draft is published.
team_id: Option<String>Identifier of the team associated with the draft. Can be used to query the team directly.
cycle_id: Option<String>Identifier of the cycle associated with the draft. Can be used to query the cycle directly. Null if no cycle is assigned.
project_id: Option<String>Identifier of the project associated with the draft. Can be used to query the project directly. Null if no project is assigned.
project_milestone_id: Option<String>Identifier of the project milestone associated with the draft. Can be used to query the project milestone directly. Null if no milestone is assigned.
creator: Option<User>The user who created the draft.
assignee_id: Option<String>Identifier of the user assigned to the draft. Can be used to query the user directly. Null if the draft is unassigned.
delegate_id: Option<String>The agent user delegated to work on the issue being drafted.
state_id: Option<String>Identifier of the workflow state associated with the draft. Can be used to query the workflow state directly. Determines the initial status the issue will have when the draft is published.
parent: Option<Box<IssueDraft>>The parent draft of the draft. Set when this draft represents a sub-issue of another draft. Null if this is a top-level draft or has a parent issue instead.
parent_id: Option<String>The ID of the parent issue draft, if any.
source_comment_id: Option<String>Identifier of the comment that the draft was created from. Set when a draft is created from an existing comment. Null if the draft was not created from a comment.
parent_issue: Option<Issue>The parent issue of the draft. Set when this draft represents a sub-issue that will be created under an existing issue. Null if this is a top-level draft or has a parent draft instead.
parent_issue_id: Option<String>The ID of the parent issue, if any.
sub_issue_sort_order: Option<f64>The order of items in the sub-draft list. Only set if the draft has parent set.
priority_label: Option<String>Label for the priority.
description_data: Option<Value>Internal The draft’s description as a Prosemirror document.
attachments: Option<Value>Serialized array of JSONs representing attachments.
needs: Option<Value>Serialized array of JSONs representing customer needs.
release_ids: Option<Vec<String>>Identifiers of the releases associated with the draft. These releases will be linked to the issue when the draft is published.
schedule: Option<Value>Serialized array of JSONs representing the recurring issue’s schedule.