pub struct IssueRelation {
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub type: Option<String>,
pub issue: Option<Issue>,
pub related_issue: Option<Issue>,
}Expand description
A relation between two issues. Issue relations represent directional relationships such as blocking, being blocked by, relating to, or duplicating another issue. Each relation connects a source issue to a related issue with a specific type describing the nature of the relationship.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
type: Option<String>The type of relationship between the source issue and the related issue. Possible values include blocks, duplicate, and related.
issue: Option<Issue>The source issue whose relationship is being described. This is the issue from which the relation originates.
The target issue that the source issue is related to. The relation type describes how the source issue relates to this issue.