pub struct User {Show 43 fields
pub id: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub archived_at: Option<DateTime<Utc>>,
pub name: Option<String>,
pub display_name: Option<String>,
pub email: Option<String>,
pub avatar_url: Option<String>,
pub disable_reason: Option<String>,
pub calendar_hash: Option<String>,
pub description: Option<String>,
pub title: Option<String>,
pub status_emoji: Option<String>,
pub status_label: Option<String>,
pub status_until_at: Option<DateTime<Utc>>,
pub timezone: Option<String>,
pub organization: Option<Box<Organization>>,
pub last_seen: Option<DateTime<Utc>>,
pub identity_provider: Option<IdentityProvider>,
pub initials: Option<String>,
pub avatar_background_color: Option<String>,
pub guest: Option<bool>,
pub app: Option<bool>,
pub is_mentionable: Option<bool>,
pub active: Option<bool>,
pub issue_drafts: Option<IssueDraftConnection>,
pub drafts: Option<DraftConnection>,
pub url: Option<String>,
pub assigned_issues: Option<IssueConnection>,
pub delegated_issues: Option<IssueConnection>,
pub created_issues: Option<IssueConnection>,
pub created_issue_count: Option<i64>,
pub teams: Option<TeamConnection>,
pub team_memberships: Option<TeamMembershipConnection>,
pub feed_facets: Option<FacetConnection>,
pub can_access_any_public_team: Option<bool>,
pub is_me: Option<bool>,
pub admin: Option<bool>,
pub owner: Option<bool>,
pub is_assignable: Option<bool>,
pub supports_agent_sessions: Option<bool>,
pub invite_hash: Option<String>,
pub git_hub_user_id: Option<String>,
}Expand description
A user that belongs to a workspace. Users can have different roles (admin, member, guest, or app) that determine their level of access. Users can be members of multiple teams, and can be active or deactivated. Guest users have limited access scoped to specific teams they are invited to.
Fields
id: Option<String>The unique identifier of the entity.
created_at: Option<DateTime<Utc>>The time at which the entity was created.
updated_at: Option<DateTime<Utc>>The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.
archived_at: Option<DateTime<Utc>>The time at which the entity was archived. Null if the entity has not been archived.
name: Option<String>The user’s full name.
display_name: Option<String>The user’s display (nick) name. Must be unique within the workspace.
email: Option<String>The user’s email address.
avatar_url: Option<String>An URL to the user’s avatar image.
disable_reason: Option<String>The reason why the user account is disabled. Null if the user is active. Possible values include admin suspension, downgrade, voluntary departure, or pending invite.
calendar_hash: Option<String>DEPRECATED Hash for the user to be used in calendar URLs.
description: Option<String>A short description of the user, such as their title or a brief bio.
title: Option<String>The user’s job title.
status_emoji: Option<String>The emoji representing the user’s current status. Null if no status is set.
status_label: Option<String>The text label of the user’s current status. Null if no status is set.
status_until_at: Option<DateTime<Utc>>The date and time at which the user’s current status should be automatically cleared. Null if the status has no expiration.
timezone: Option<String>The local timezone of the user.
organization: Option<Box<Organization>>The workspace that the user belongs to.
last_seen: Option<DateTime<Utc>>The last time the user was seen online. Updated based on user activity. Null if the user has never been seen.
identity_provider: Option<IdentityProvider>INTERNAL Identity provider the user is managed by.
initials: Option<String>The initials of the user.
avatar_background_color: Option<String>The background color of the avatar for users without set avatar.
guest: Option<bool>Whether the user is a guest in the workspace and limited to accessing a subset of teams.
app: Option<bool>Whether the user is an app.
is_mentionable: Option<bool>Whether the user is mentionable.
active: Option<bool>Whether the user account is active or disabled (suspended).
issue_drafts: Option<IssueDraftConnection>Issue drafts that the user has created but not yet submitted.
drafts: Option<DraftConnection>The user’s saved drafts.
url: Option<String>User’s profile URL.
assigned_issues: Option<IssueConnection>Issues assigned to the user.
delegated_issues: Option<IssueConnection>Issues delegated to this user.
created_issues: Option<IssueConnection>Issues created by the user.
created_issue_count: Option<i64>Number of issues created.
teams: Option<TeamConnection>Teams the user is a member of. Supports filtering by team properties.
team_memberships: Option<TeamMembershipConnection>Memberships associated with the user. For easier access of the same data, use teams query.
feed_facets: Option<FacetConnection>INTERNAL The user’s pinned feeds.
can_access_any_public_team: Option<bool>Whether this user can access any public team in the workspace. True for non-guest members and app users with public team access.
is_me: Option<bool>Whether the user is the currently authenticated user.
admin: Option<bool>Whether the user is a workspace administrator. On Free plans, all members are treated as admins.
owner: Option<bool>Whether the user is a workspace owner, which is the highest permission level.
is_assignable: Option<bool>Whether the user can be assigned to issues. Regular users are always assignable; app users are assignable only if they have the app:assignable scope.
supports_agent_sessions: Option<bool>Whether this agent user supports agent sessions.
invite_hash: Option<String>DEPRECATED Unique hash for the user to be used in invite URLs.
git_hub_user_id: Option<String>The user’s GitHub user ID.