pub struct ViewPreferencesValues {Show 209 fields
pub layout: Option<String>,
pub view_ordering: Option<String>,
pub view_ordering_direction: Option<String>,
pub issue_grouping: Option<String>,
pub issue_sub_grouping: Option<String>,
pub issue_nesting: Option<String>,
pub show_completed_issues: Option<String>,
pub show_parents: Option<bool>,
pub show_sub_issues: Option<bool>,
pub show_sub_team_issues: Option<bool>,
pub show_supervised_issues: Option<bool>,
pub show_triage_issues: Option<bool>,
pub show_snoozed_items: Option<bool>,
pub show_only_snoozed_items: Option<bool>,
pub show_archived_items: Option<bool>,
pub show_read_items: Option<bool>,
pub show_unread_items_first: Option<bool>,
pub closed_issues_ordered_by_recency: Option<bool>,
pub show_empty_groups: Option<bool>,
pub show_empty_groups_board: Option<bool>,
pub show_empty_groups_list: Option<bool>,
pub show_empty_sub_groups: Option<bool>,
pub show_empty_sub_groups_board: Option<bool>,
pub show_empty_sub_groups_list: Option<bool>,
pub issue_grouping_label_group_id: Option<String>,
pub issue_sub_grouping_label_group_id: Option<String>,
pub field_id: Option<bool>,
pub field_status: Option<bool>,
pub field_priority: Option<bool>,
pub field_date_created: Option<bool>,
pub field_date_updated: Option<bool>,
pub field_date_archived: Option<bool>,
pub field_date_my_activity: Option<bool>,
pub field_assignee: Option<bool>,
pub field_estimate: Option<bool>,
pub field_pull_requests: Option<bool>,
pub field_preview_links: Option<bool>,
pub field_sentry_issues: Option<bool>,
pub field_due_date: Option<bool>,
pub field_link_count: Option<bool>,
pub field_customer_count: Option<bool>,
pub field_customer_revenue: Option<bool>,
pub field_sla: Option<bool>,
pub field_labels: Option<bool>,
pub field_project: Option<bool>,
pub field_cycle: Option<bool>,
pub field_milestone: Option<bool>,
pub field_release: Option<bool>,
pub field_time_in_current_status: Option<bool>,
pub hidden_columns: Option<Vec<String>>,
pub hidden_rows: Option<Vec<String>>,
pub hidden_groups_list: Option<Vec<String>>,
pub column_order_board: Option<Vec<String>>,
pub column_order_list: Option<Vec<String>>,
pub project_layout: Option<String>,
pub project_view_ordering: Option<String>,
pub project_grouping: Option<String>,
pub project_sub_grouping: Option<String>,
pub project_group_ordering: Option<String>,
pub project_grouping_date_resolution: Option<String>,
pub show_completed_projects: Option<String>,
pub project_grouping_label_group_id: Option<String>,
pub project_sub_grouping_label_group_id: Option<String>,
pub project_label_group_columns: Option<Vec<ViewPreferencesProjectLabelGroupColumn>>,
pub show_sub_team_projects: Option<bool>,
pub show_sub_initiative_projects: Option<bool>,
pub project_show_empty_groups: Option<String>,
pub project_show_empty_groups_list: Option<String>,
pub project_show_empty_groups_timeline: Option<String>,
pub project_show_empty_groups_board: Option<String>,
pub project_show_empty_sub_groups: Option<String>,
pub project_show_empty_sub_groups_list: Option<String>,
pub project_show_empty_sub_groups_timeline: Option<String>,
pub project_show_empty_sub_groups_board: Option<String>,
pub project_field_status: Option<bool>,
pub project_field_priority: Option<bool>,
pub project_field_lead: Option<bool>,
pub project_field_health: Option<bool>,
pub project_field_members: Option<bool>,
pub project_field_start_date: Option<bool>,
pub project_field_target_date: Option<bool>,
pub project_field_teams: Option<bool>,
pub project_field_roadmaps: Option<bool>,
pub project_field_initiatives: Option<bool>,
pub project_field_milestone: Option<bool>,
pub project_field_description: Option<bool>,
pub project_field_predictions: Option<bool>,
pub project_field_relations: Option<bool>,
pub project_field_rollout_stage: Option<bool>,
pub project_field_activity: Option<bool>,
pub project_field_customer_count: Option<bool>,
pub project_field_customer_revenue: Option<bool>,
pub project_field_labels: Option<bool>,
pub project_field_date_created: Option<bool>,
pub project_field_date_updated: Option<bool>,
pub project_field_date_completed: Option<bool>,
pub project_field_status_timeline: Option<bool>,
pub project_field_lead_timeline: Option<bool>,
pub project_field_health_timeline: Option<bool>,
pub project_field_milestone_timeline: Option<bool>,
pub project_field_predictions_timeline: Option<bool>,
pub project_field_relations_timeline: Option<bool>,
pub project_field_description_board: Option<bool>,
pub project_field_members_board: Option<bool>,
pub project_field_members_list: Option<bool>,
pub project_field_members_timeline: Option<bool>,
pub project_field_roadmaps_board: Option<bool>,
pub project_field_roadmaps_list: Option<bool>,
pub project_field_roadmaps_timeline: Option<bool>,
pub project_field_teams_board: Option<bool>,
pub project_field_teams_list: Option<bool>,
pub project_field_teams_timeline: Option<bool>,
pub project_zoom_level: Option<String>,
pub timeline_zoom_scale: Option<f64>,
pub timeline_chronology_show_cycle_team_ids: Option<Vec<String>>,
pub timeline_chronology_show_week_numbers: Option<bool>,
pub initiative_grouping: Option<String>,
pub initiatives_view_ordering: Option<String>,
pub initiative_field_projects: Option<bool>,
pub initiative_field_teams: Option<bool>,
pub initiative_field_description: Option<bool>,
pub initiative_field_owner: Option<bool>,
pub initiative_field_start_date: Option<bool>,
pub initiative_field_target_date: Option<bool>,
pub initiative_field_date_completed: Option<bool>,
pub initiative_field_date_updated: Option<bool>,
pub initiative_field_date_created: Option<bool>,
pub initiative_field_status: Option<bool>,
pub initiative_field_activity: Option<bool>,
pub initiative_field_initiative_health: Option<bool>,
pub initiative_field_health: Option<bool>,
pub show_nested_initiatives: Option<bool>,
pub customers_view_ordering: Option<String>,
pub customer_field_request_count: Option<bool>,
pub customer_field_domains: Option<bool>,
pub customer_field_owner: Option<bool>,
pub customer_field_revenue: Option<bool>,
pub customer_field_size: Option<bool>,
pub customer_field_source: Option<bool>,
pub customer_field_status: Option<bool>,
pub customer_field_tier: Option<bool>,
pub customer_page_needs_view_grouping: Option<String>,
pub customer_page_needs_view_ordering: Option<String>,
pub customer_page_needs_show_important_first: Option<bool>,
pub customer_page_needs_show_completed_issues_and_projects: Option<String>,
pub customer_page_needs_field_issue_identifier: Option<bool>,
pub customer_page_needs_field_issue_priority: Option<bool>,
pub customer_page_needs_field_issue_status: Option<bool>,
pub customer_page_needs_field_issue_target_due_date: Option<bool>,
pub embedded_customer_needs_view_ordering: Option<String>,
pub embedded_customer_needs_show_important_first: Option<bool>,
pub project_customer_needs_view_grouping: Option<String>,
pub project_customer_needs_view_ordering: Option<String>,
pub project_customer_needs_show_important_first: Option<bool>,
pub project_customer_needs_show_completed_issues_last: Option<bool>,
pub team_view_ordering: Option<String>,
pub team_field_identifier: Option<bool>,
pub team_field_membership: Option<bool>,
pub team_field_owner: Option<bool>,
pub team_field_members: Option<bool>,
pub team_field_projects: Option<bool>,
pub team_field_cycle: Option<bool>,
pub team_field_date_created: Option<bool>,
pub team_field_date_updated: Option<bool>,
pub custom_views_ordering: Option<String>,
pub custom_view_field_owner: Option<bool>,
pub custom_view_field_visibility: Option<bool>,
pub custom_view_field_date_created: Option<bool>,
pub custom_view_field_date_updated: Option<bool>,
pub dashboards_ordering: Option<String>,
pub dashboard_field_owner: Option<bool>,
pub dashboard_field_date_created: Option<bool>,
pub dashboard_field_date_updated: Option<bool>,
pub workspace_members_view_ordering: Option<String>,
pub member_field_status: Option<bool>,
pub member_field_joined: Option<bool>,
pub member_field_teams: Option<bool>,
pub release_pipeline_grouping: Option<String>,
pub release_pipelines_view_ordering: Option<String>,
pub release_pipeline_field_type: Option<bool>,
pub release_pipeline_field_teams: Option<bool>,
pub release_pipeline_field_releases: Option<bool>,
pub release_pipeline_field_latest_release: Option<bool>,
pub scheduled_pipeline_releases_view_ordering: Option<String>,
pub scheduled_pipeline_releases_view_grouping: Option<String>,
pub scheduled_pipeline_release_field_version: Option<bool>,
pub scheduled_pipeline_release_field_release_date: Option<bool>,
pub scheduled_pipeline_release_field_completion: Option<bool>,
pub scheduled_pipeline_release_field_description: Option<bool>,
pub continuous_pipeline_releases_view_grouping: Option<String>,
pub continuous_pipeline_release_field_version: Option<bool>,
pub continuous_pipeline_release_field_release_date: Option<bool>,
pub search_view_ordering: Option<String>,
pub search_result_type: Option<String>,
pub inbox_view_ordering: Option<String>,
pub triage_view_ordering: Option<String>,
pub focus_view_grouping: Option<String>,
pub focus_view_ordering: Option<String>,
pub focus_view_ordering_direction: Option<String>,
pub review_grouping: Option<String>,
pub review_view_ordering: Option<String>,
pub show_completed_reviews: Option<String>,
pub show_draft_reviews: Option<bool>,
pub review_field_avatar: Option<bool>,
pub review_field_preview_links: Option<bool>,
pub review_field_repository: Option<bool>,
pub review_field_identifier: Option<bool>,
pub review_field_checks: Option<bool>,
pub show_completed_agent_sessions: Option<String>,
}Expand description
The computed view preferences values for a view, containing all display settings such as layout mode, grouping, sorting, field visibility, and other visual configuration. These values represent the merged result of organization defaults and user overrides.
Fields
layout: Option<String>The issue layout type.
view_ordering: Option<String>The issue ordering.
view_ordering_direction: Option<String>The direction of the issue ordering.
issue_grouping: Option<String>The issue grouping.
issue_sub_grouping: Option<String>The issue sub-grouping.
issue_nesting: Option<String>How sub-issues should be nested and displayed.
show_completed_issues: Option<String>Whether completed issues are shown and for how long.
show_parents: Option<bool>Whether to show parent issues for sub-issues.
show_sub_issues: Option<bool>Whether to show sub-issues.
show_sub_team_issues: Option<bool>Whether to show sub-team issues.
show_supervised_issues: Option<bool>Whether to show supervised issues.
show_triage_issues: Option<bool>Whether to show triage issues.
show_snoozed_items: Option<bool>Whether to show snoozed items.
show_only_snoozed_items: Option<bool>Whether to show only snoozed items.
show_archived_items: Option<bool>Whether to show archived items.
show_read_items: Option<bool>Whether to show read items.
show_unread_items_first: Option<bool>Whether to show unread items first.
closed_issues_ordered_by_recency: Option<bool>Whether issues in closed columns should be ordered by recency.
show_empty_groups: Option<bool>Whether to show empty groups.
show_empty_groups_board: Option<bool>Whether to show empty groups on the board layout.
show_empty_groups_list: Option<bool>Whether to show empty groups on the list layout.
show_empty_sub_groups: Option<bool>Whether to show empty sub-groups.
show_empty_sub_groups_board: Option<bool>Whether to show empty sub-groups on the board layout.
show_empty_sub_groups_list: Option<bool>Whether to show empty sub-groups on the list layout.
issue_grouping_label_group_id: Option<String>The label group ID used for issue grouping.
issue_sub_grouping_label_group_id: Option<String>The label group ID used for issue sub-grouping.
field_id: Option<bool>Whether to show the issue identifier field.
field_status: Option<bool>Whether to show the issue status field.
field_priority: Option<bool>Whether to show the issue priority field.
field_date_created: Option<bool>Whether to show the issue creation date field.
field_date_updated: Option<bool>Whether to show the issue updated date field.
field_date_archived: Option<bool>Whether to show the issue archived date field.
field_date_my_activity: Option<bool>Whether to show the issue last activity date field.
field_assignee: Option<bool>Whether to show the issue assignee field.
field_estimate: Option<bool>Whether to show the issue estimate field.
field_pull_requests: Option<bool>Whether to show the pull requests field.
field_preview_links: Option<bool>Whether to show preview links.
field_sentry_issues: Option<bool>Whether to show the Sentry issues field.
field_due_date: Option<bool>Whether to show the due date field.
field_link_count: Option<bool>Whether to show the link count field.
field_customer_count: Option<bool>Whether to show the customer request count field.
field_customer_revenue: Option<bool>Whether to show the customer revenue field.
field_sla: Option<bool>Whether to show the SLA field.
field_labels: Option<bool>Whether to show the labels field.
field_project: Option<bool>Whether to show the project field.
field_cycle: Option<bool>Whether to show the cycle field.
field_milestone: Option<bool>Whether to show the milestone field.
field_release: Option<bool>Whether to show the release field.
field_time_in_current_status: Option<bool>Whether to show the time in current status field.
List of column model IDs which should be hidden on a board.
List of row model IDs which should be hidden on a board.
List of group model IDs which should be hidden on a list.
column_order_board: Option<Vec<String>>Custom ordering of groups on the board layout.
column_order_list: Option<Vec<String>>Custom ordering of groups on the list layout.
project_layout: Option<String>The project layout type.
project_view_ordering: Option<String>The project ordering.
project_grouping: Option<String>The project grouping.
project_sub_grouping: Option<String>The project sub-grouping.
project_group_ordering: Option<String>The ordering of project groups.
project_grouping_date_resolution: Option<String>The date resolution when grouping projects by date.
show_completed_projects: Option<String>Whether completed projects are shown and for how long.
project_grouping_label_group_id: Option<String>The label group ID used for project grouping.
project_sub_grouping_label_group_id: Option<String>The label group ID used for project sub-grouping.
project_label_group_columns: Option<Vec<ViewPreferencesProjectLabelGroupColumn>>The project label group columns configuration.
show_sub_team_projects: Option<bool>Whether to show sub-team projects.
show_sub_initiative_projects: Option<bool>Whether to show sub-initiative projects.
project_show_empty_groups: Option<String>How to show empty project groups.
project_show_empty_groups_list: Option<String>How to show empty project groups on the list layout.
project_show_empty_groups_timeline: Option<String>How to show empty project groups on the timeline layout.
project_show_empty_groups_board: Option<String>How to show empty project groups on the board layout.
project_show_empty_sub_groups: Option<String>How to show empty project sub-groups.
project_show_empty_sub_groups_list: Option<String>How to show empty project sub-groups on the list layout.
project_show_empty_sub_groups_timeline: Option<String>How to show empty project sub-groups on the timeline layout.
project_show_empty_sub_groups_board: Option<String>How to show empty project sub-groups on the board layout.
project_field_status: Option<bool>Whether to show the project status field.
project_field_priority: Option<bool>Whether to show the project priority field.
project_field_lead: Option<bool>Whether to show the project lead field.
project_field_health: Option<bool>Whether to show the project health field.
project_field_members: Option<bool>Whether to show the project members field.
project_field_start_date: Option<bool>Whether to show the project start date field.
project_field_target_date: Option<bool>Whether to show the project target date field.
project_field_teams: Option<bool>Whether to show the project teams field.
project_field_roadmaps: Option<bool>Whether to show the project roadmaps field.
project_field_initiatives: Option<bool>Whether to show the project initiatives field.
project_field_milestone: Option<bool>Whether to show the project milestone field.
project_field_description: Option<bool>Whether to show the project description field.
project_field_predictions: Option<bool>Whether to show the project predictions field.
project_field_relations: Option<bool>Whether to show the project relations field.
project_field_rollout_stage: Option<bool>Whether to show the project rollout stage field.
project_field_activity: Option<bool>Whether to show the project activity field.
project_field_customer_count: Option<bool>Whether to show the project customer count field.
project_field_customer_revenue: Option<bool>Whether to show the project customer revenue field.
project_field_labels: Option<bool>Whether to show the project labels field.
project_field_date_created: Option<bool>Whether to show the project creation date field.
project_field_date_updated: Option<bool>Whether to show the project updated date field.
project_field_date_completed: Option<bool>Whether to show the project completion date field.
project_field_status_timeline: Option<bool>Whether to show the project status field on the timeline.
project_field_lead_timeline: Option<bool>Whether to show the project lead field on the timeline.
project_field_health_timeline: Option<bool>Whether to show the project health field on the timeline.
project_field_milestone_timeline: Option<bool>Whether to show the project milestone field on the timeline.
project_field_predictions_timeline: Option<bool>Whether to show the project predictions field on the timeline.
project_field_relations_timeline: Option<bool>Whether to show the project relations field on the timeline.
project_field_description_board: Option<bool>Whether to show the project description field on the board.
project_field_members_board: Option<bool>Whether to show the project members field on the board.
project_field_members_list: Option<bool>Whether to show the project members field on the list.
project_field_members_timeline: Option<bool>Whether to show the project members field on the timeline.
project_field_roadmaps_board: Option<bool>Whether to show the project roadmaps field on the board.
project_field_roadmaps_list: Option<bool>Whether to show the project roadmaps field on the list.
project_field_roadmaps_timeline: Option<bool>Whether to show the project roadmaps field on the timeline.
project_field_teams_board: Option<bool>Whether to show the project teams field on the board.
project_field_teams_list: Option<bool>Whether to show the project teams field on the list.
project_field_teams_timeline: Option<bool>Whether to show the project teams field on the timeline.
project_zoom_level: Option<String>The zoom level for the timeline view.
timeline_zoom_scale: Option<f64>The zoom scale for the timeline view.
timeline_chronology_show_cycle_team_ids: Option<Vec<String>>Selected team IDs to show cycles for in timeline chronology bar.
timeline_chronology_show_week_numbers: Option<bool>Whether to show week numbers in timeline chronology bar.
initiative_grouping: Option<String>The initiative grouping.
initiatives_view_ordering: Option<String>The initiative ordering.
initiative_field_projects: Option<bool>Whether to show the initiative projects field.
initiative_field_teams: Option<bool>Whether to show the initiative teams field.
initiative_field_description: Option<bool>Whether to show the initiative description field.
initiative_field_owner: Option<bool>Whether to show the initiative owner field.
initiative_field_start_date: Option<bool>Whether to show the initiative start date field.
initiative_field_target_date: Option<bool>Whether to show the initiative target date field.
initiative_field_date_completed: Option<bool>Whether to show the initiative completed date field.
initiative_field_date_updated: Option<bool>Whether to show the initiative updated date field.
initiative_field_date_created: Option<bool>Whether to show the initiative created date field.
initiative_field_status: Option<bool>Whether to show the initiative status field.
initiative_field_activity: Option<bool>Whether to show the initiative activity field.
initiative_field_initiative_health: Option<bool>Whether to show the initiative health field.
initiative_field_health: Option<bool>Whether to show the initiative active projects health field.
show_nested_initiatives: Option<bool>Whether to show sub-initiatives nested.
customers_view_ordering: Option<String>The customers view ordering.
customer_field_request_count: Option<bool>Whether to show the customer request count field.
customer_field_domains: Option<bool>Whether to show the customer domains field.
customer_field_owner: Option<bool>Whether to show the customer owner field.
customer_field_revenue: Option<bool>Whether to show the customer revenue field.
customer_field_size: Option<bool>Whether to show the customer size field.
customer_field_source: Option<bool>Whether to show the customer source field.
customer_field_status: Option<bool>Whether to show the customer status field.
customer_field_tier: Option<bool>Whether to show the customer tier field.
customer_page_needs_view_grouping: Option<String>The customer page needs view grouping.
customer_page_needs_view_ordering: Option<String>The customer page needs view ordering.
customer_page_needs_show_important_first: Option<bool>Whether to show important customer needs first.
customer_page_needs_show_completed_issues_and_projects: Option<String>Whether to show completed issues and projects in the customer page.
customer_page_needs_field_issue_identifier: Option<bool>Whether to show the issue identifier field in the customer page.
customer_page_needs_field_issue_priority: Option<bool>Whether to show the issue priority field in the customer page.
customer_page_needs_field_issue_status: Option<bool>Whether to show the issue status field in the customer page.
customer_page_needs_field_issue_target_due_date: Option<bool>Whether to show the issue due date field in the customer page.
embedded_customer_needs_view_ordering: Option<String>The embedded customer needs view ordering.
embedded_customer_needs_show_important_first: Option<bool>Whether to show important embedded customer needs first.
project_customer_needs_view_grouping: Option<String>The project customer needs view grouping.
project_customer_needs_view_ordering: Option<String>The project customer needs view ordering.
project_customer_needs_show_important_first: Option<bool>Whether to show important project customer needs first.
project_customer_needs_show_completed_issues_last: Option<bool>Whether to show completed issues last in project customer needs.
team_view_ordering: Option<String>The team view ordering.
team_field_identifier: Option<bool>Whether to show the team identifier field.
team_field_membership: Option<bool>Whether to show the team membership field.
team_field_owner: Option<bool>Whether to show the team owner field.
team_field_members: Option<bool>Whether to show the team members field.
team_field_projects: Option<bool>Whether to show the team projects field.
team_field_cycle: Option<bool>Whether to show the team cycle field.
team_field_date_created: Option<bool>Whether to show the team creation date field.
team_field_date_updated: Option<bool>Whether to show the team updated date field.
custom_views_ordering: Option<String>The custom views ordering.
custom_view_field_owner: Option<bool>Whether to show the custom view owner field.
custom_view_field_visibility: Option<bool>Whether to show the custom view visibility field.
custom_view_field_date_created: Option<bool>Whether to show the custom view creation date field.
custom_view_field_date_updated: Option<bool>Whether to show the custom view updated date field.
dashboards_ordering: Option<String>The dashboards ordering.
dashboard_field_owner: Option<bool>Whether to show the dashboard owner field.
dashboard_field_date_created: Option<bool>Whether to show the dashboard creation date field.
dashboard_field_date_updated: Option<bool>Whether to show the dashboard updated date field.
workspace_members_view_ordering: Option<String>The workspace members view ordering.
member_field_status: Option<bool>Whether to show the member status field.
member_field_joined: Option<bool>Whether to show the member joined date field.
member_field_teams: Option<bool>Whether to show the member teams field.
release_pipeline_grouping: Option<String>The release pipeline grouping.
release_pipelines_view_ordering: Option<String>The release pipelines view ordering.
release_pipeline_field_type: Option<bool>Whether to show the type field for release pipelines.
release_pipeline_field_teams: Option<bool>Whether to show the teams field for release pipelines.
release_pipeline_field_releases: Option<bool>Whether to show the releases field for release pipelines.
release_pipeline_field_latest_release: Option<bool>Whether to show the latest release field for release pipelines.
scheduled_pipeline_releases_view_ordering: Option<String>The scheduled pipeline releases view ordering.
scheduled_pipeline_releases_view_grouping: Option<String>The scheduled pipeline releases view grouping.
scheduled_pipeline_release_field_version: Option<bool>Whether to show the version field for scheduled pipeline releases.
scheduled_pipeline_release_field_release_date: Option<bool>Whether to show the release date field for scheduled pipeline releases.
scheduled_pipeline_release_field_completion: Option<bool>Whether to show the completion field for scheduled pipeline releases.
scheduled_pipeline_release_field_description: Option<bool>Whether to show the description field for scheduled pipeline releases.
continuous_pipeline_releases_view_grouping: Option<String>The continuous pipeline releases view grouping.
continuous_pipeline_release_field_version: Option<bool>Whether to show the version field for continuous pipeline releases.
continuous_pipeline_release_field_release_date: Option<bool>Whether to show the release date field for continuous pipeline releases.
search_view_ordering: Option<String>The search view ordering.
search_result_type: Option<String>The search result type filter.
inbox_view_ordering: Option<String>The inbox view ordering.
triage_view_ordering: Option<String>The triage view ordering.
focus_view_grouping: Option<String>The focus view grouping.
focus_view_ordering: Option<String>The focus view ordering.
focus_view_ordering_direction: Option<String>The focus view ordering direction.
review_grouping: Option<String>The review grouping.
review_view_ordering: Option<String>The review view ordering.
show_completed_reviews: Option<String>Whether completed reviews are shown and for how long.
show_draft_reviews: Option<bool>Whether to show draft reviews.
review_field_avatar: Option<bool>Whether to show the review avatar field.
review_field_preview_links: Option<bool>Whether to show the review preview links field.
review_field_repository: Option<bool>Whether to show the review repository field.
review_field_identifier: Option<bool>Whether to show the review identifier field.
review_field_checks: Option<bool>Whether to show the review checks field.
show_completed_agent_sessions: Option<String>Whether completed agent sessions are shown and for how long.