WorkflowState

Struct WorkflowState 

pub struct WorkflowState {
    pub id: Option<String>,
    pub created_at: Option<DateTime<Utc>>,
    pub updated_at: Option<DateTime<Utc>>,
    pub archived_at: Option<DateTime<Utc>>,
    pub name: Option<String>,
    pub color: Option<String>,
    pub description: Option<String>,
    pub position: Option<f64>,
    pub type: Option<String>,
    pub team: Option<Box<Team>>,
    pub inherited_from: Option<Box<WorkflowState>>,
    pub issues: Option<IssueConnection>,
}
A state in a team’s workflow, representing an issue status such as Triage, Backlog, Todo, In Progress, In Review, Done, or Canceled. Each team has its own set of workflow states that define the progression of issues through the team’s process. Workflow states have a type that categorizes them (triage, backlog, unstarted, started, completed, canceled), a position that determines their display order, and a color for visual identification. States can be inherited from parent teams to sub-teams.

Fields

id: Option<String>

The unique identifier of the entity.

created_at: Option<DateTime<Utc>>

The time at which the entity was created.

updated_at: Option<DateTime<Utc>>

The last time at which the entity was meaningfully updated. This is the same as the creation time if the entity hasn’t been updated after creation.

archived_at: Option<DateTime<Utc>>

The time at which the entity was archived. Null if the entity has not been archived.

name: Option<String>

The state’s human-readable name (e.g., ‘In Progress’, ‘Done’, ‘Backlog’).

color: Option<String>

The state’s UI color as a HEX string.

description: Option<String>

Description of the state.

position: Option<f64>

The position of the state in the team’s workflow. States are displayed in ascending order of position within their type group.

type: Option<String>

The type of the state. One of “triage”, “backlog”, “unstarted”, “started”, “completed”, “canceled”, “duplicate”.

team: Option<Box<Team>>

The team that this workflow state belongs to. Each team has its own set of workflow states.

inherited_from: Option<Box<WorkflowState>>

The parent team’s workflow state that this state was inherited from. Null if the state is not inherited from a parent team.

issues: Option<IssueConnection>

Issues that currently have this workflow state. Returns a paginated and filterable list of issues.